/* messages.c
 * Error, warning, and info messages, in your host language,
 * as determined by the variable $LANG.
 * Messages can be generated in iso-8859-1, but utf8 is recommended.
 * This file is part of the edbrowse project, released under GPL.
 */

#include "eb.h"

#include <locale.h>

/*********************************************************************
Message strings are in utf8.
If your system expects iso8859-x, don't let edbrowse convert
this file from utf8 to iso8859-x.
Use the iu command to disable this feature.
Multiple codepages are used in this file,
and conversion will never get everything right.
You could screw up some or all of the messages!
You have to edit it as is, without conversions.
*********************************************************************/

/* Arrays of messages, one array for each language. */

static const char *englishMessages[] = {
	"EOF",
	"no file",
	"none",
	"substitutions global",
	"substitutions local",
	"case insensitive",
	"case sensitive",
	"directories readonly",
	"directories writable",
	"directories writable with delete",
	"no http redirection",
	"http redirection",
	"do not send referrer",
	"send referrer",
	"javascript disabled",
	"javascript enabled",
	"treating binary like text",
	"watching for binary files",
	"passive mode",
	"active mode",
	"Javascript engine has failed; all current javascript sessions have been closed.",
	"don't verify ssl connections (less secure)",
	"verify ssl connections",
	"don't show hidden files in directory mode",
	"show hidden files in directory mode",
	"Unable to fork child process for edbrowse-js, javascript has been disabled.",
	"Unable to exec edbrowse-js, javascript has been disabled.",
	"end markers off",
	"end markers on listed lines",
	"end markers on",
	"javascript disabled, no action taken",
	"javascript is disabled, going straight to the url",
	"redirection interrupted by user",
	"empty",
	"new session",
	"no trailing newline",
	"directory mode",
	"binary data",
	"ok",
	" [binary]",
	"no title",
	"no description",
	"no keywords",
	"session %d\n",
	"SendMail link.  Compose your mail, type sm to send, then ^ to get back.",
	"line %d has been updated\n",
	"no subject",
	"no config file present",
	".ebrc config file does not contain a subjfilter{...} block",
	"interrupt, type qt to quit completely",
	"edbrowse ready",
	"entered command line contains nulls; you can use \\0 in a search/replace string to indicate null",
	"authorization requested - type x to abort.",
	"too many redirections",
	"success",
	"directory",
	"redirect to %s delayed by %d seconds\n",
	"Username: ",
	"user name too long, limit %d characters",
	"Password: ",
	"password too long, limit %d characters",
	"Unable to communicate with edbrowse-js, javascript has been disabled.",
	"warning, the directory is inaccessible - the listing will be empty",
	"disaster, error message length %d is too long\n",
	"line %d: ",
	"browse error: ",
	"buffer %d has been updated\n",
	"no options",
	"form has been reset",
	"submitting form",
	"A separate window has been created in buffer %d\n",
	" many",
	" recommended",
	"]",
	"no options contain the string %s\n",
	"sending mail to %s\n",
	"Your information has been sent; watch for a reply via return mail.",
	"junk",
	"quit",
	"next",
	"delete",
	"ip delete",
	"-p option disables this feature",
	"Unable to set up the javascript runtime environment, javascript has been disabled.",
	"end of message",
	"not yet implemented",
	"filename: ",
	"Sorry, file %s already exists.\n",
	"abbreviated ",
	"empty attachment",
	"attachment ",
	"no buffers left, atachment discarded",
	"could not copy the attachment into buffer %d",
	"cannot create file %s, attachment is discarded\n",
	"cannot write to file %s, attachment is discarded\n",
	"no mail",
	"%d messages\n",
	"Javascript interprocess messages are out of sync.",
	" from ",
	"?\tprint this help message.\nq\tquit this program.\nspace\tread more of this mail message.\nn\tmove on to the next mail message.\nd\tdelete this message.\nw\twrite this message to a file and delete it.\nu\twrite this message unformatted to a file and delete it.",
	"cannot create file %s\n",
	"cannot write to file %s\n",
	"mail saved, %d bytes",
	" appended",
	"This page is finished, please use your back key or quit.",
	"Sorry, innerText update not yet implemented.",
	"no errors",
	"proxy authentication for a non-proxy url",
	"session %d is not active",
	"session 0 is invalid",
	"session %d is out of bounds, limit %d",
	"you are already in session %d",
	"expecting `w'",
	"expecting `w' on session %d",
	"Your limit of 170 million lines has been reached.\nSave your files, then exit and restart this program.",
	"absolute path name too long, limit %d chars",
	"directories are readonly, type dw to enable directory writes",
	"could not create .Trash under your home directory, to hold the deleted files",
	"could not remove file %s",
	"Could not move %s to the trash bin, set dx mode to actually remove the file",
	"destination lies inside the block to be moved or copied",
	"no change",
	"cannot join one line",
	"cannot read from the database into another file",
	"cannot read different tables into the same session",
	"missing file name",
	"empty domain in url",
	"cannot write to a url",
	"cannot write to a database table",
	"cannot write an empty file",
	"cannot create %s",
	"cannot write to %s",
	"session is not interactive",
	"line %c is out of range",
	"cannot embed nulls in a shell command",
	"label %c not set",
	"invalid delimiter",
	"no remembered search string",
	"no remembered replacement string",
	"regular expression too long",
	"line ends in backslash",
	"unexpected closing )",
	"replacement string can only use $1 through $9",
	"%s modifier has no preceding character",
	"no closing ]",
	"no closing )",
	"empty buffer",
	"error in regular expression, %s",
	"unexpected error while evaluating the regular expression at line %d",
	"search string not found",
	"line number too large",
	"negative line number",
	"no regular expression after %c",
	"missing delimiter",
	"no lines match the g pattern",
	"all lines match the v pattern",
	"none of the marked lines were successfully modified",
	"operation interrupted",
	"no match",
	"Javascript objects are missing or misconfigured.",
	"agent number %c is not defined",
	"could not print new directory",
	"could not establish current directory",
	"invalid directory",
	"cannot play audio from an empty buffer",
	"cannot play audio in browse mode",
	"cannot play audio in directory mode",
	"cannot play audio in database mode",
	"file has no suffix, use mt.xxx to specify your own suffix",
	"suffix is limited to 5 characters",
	"suffix .%s is not a recognized mime type, please check your config file.",
	"no file name or url to refresh",
	"not in database mode",
	"not in browse mode",
	"file name does not contain /",
	"file name ends in /",
	"invalid characters after the sm command",
	"you must specify exactly one of %s after the B command",
	"line does not contain an open %c",
	"both %c and %c are unbalanced on this line, try B%c or B%c",
	"line does not contain an unbalanced brace, parenthesis, or bracket",
	"cannot find the line that balances %c",
	"session %d is currently in browse mode",
	"session %d is currently in directory mode",
	"no file name",
	"end of buffer",
	"no more lines to join",
	"bad range",
	"cannot break lines in directory mode",
	"cannot break lines in database mode",
	"cannot break lines in browse mode",
	"unknown command %c",
	"%c not available in directory mode",
	"%c not available in database mode",
	"%c not available in browse mode",
	"zero line number",
	"no space after command",
	"the %c command cannot be applied globally",
	"invalid move/copy destination",
	"unexpected text after the %c command",
	"nothing to undo",
	"please enter k[a-z]",
	"cannot label an entire range",
	"backing up 0 is invalid",
	"warning: no buffers available to handle the ancillary window",
	"unexpected text after the q command",
	"cannot change the name of a directory",
	"cannot change the name of a table",
	"cannot append to another buffer",
	"no file specified",
	"cannot write to the directory; files are modified as you go",
	"cannot write to the database; rows are modified as you go",
	"unexpected text after the ^ command",
	"no previous text",
	"unexpected text after the M command",
	"destination session not specified",
	"no previous text, cannot back up",
	"cannot apply the g command to a range",
	"g not available in database mode",
	"cannot apply the i%c command to a range",
	"cannot use i< in a global command",
	"buffer %d is empty",
	"buffer %d contains more than one line",
	"cannot open %s",
	"cannot read from %s",
	"input text contains nulls",
	"line contains an embeded carriage return",
	"first line of %s is too long",
	"file is currently in buffer - please use the rf command to refresh",
	"cannot browse a binary file",
	"cannot browse an empty file",
	"this doesn't look like browsable text",
	"already browsing",
	"label %s is not found",
	"i not available in browse mode",
	"cannot run an insert command from an edbrowse function",
	"Unable to communicate with edbrowse-js, javascript is closed.",
	"command %c not yet implemented",
	"%d is out of range",
	"no options contain the string %s",
	"multiple options contain the string %s",
	"this is a button; use i* to push the button",
	"this is a submit button; use i* to push the button",
	"this is a reset button; use i* to push the button",
	"this is a textarea, you must edit it from session %d",
	"readonly field",
	"input field cannot contain a newline character",
	"input too long, limit %d characters",
	"field must be set to + or -",
	"you cannot clear a radio button; you must set another one",
	"%s is not an accessible file",
	"number expected",
	"session %d contains nulls",
	"sending a file requires method=post and enctype=multipart/form-data",
	"this is an input field, not a button",
	"this button is not part of a form",
	"no javascript associated with this button",
	"form does not include a destination url",
	"the action of the form is not a url",
	"javascript is disabled, cannot activate this form",
	"This form has changed from https to http, and is now insecure",
	"cannot submit using protocol %s",
	"%d is out of range, please use %c1 through %c%d",
	"%d is out of range, please use %c1, or simply %c",
	"cannot replace multiple instances of the empty string",
	"download aborted.",
	"no regular expression after %c",
	"multiple numbers after the third delimiter",
	"unexpected substitution suffix after the third delimiter",
	"cannot use both a numeric suffix and the `g' suffix simultaneously",
	"sorry, cannot apply the bl command to lines longer than %d bytes",
	"replacement data contains newlines",
	"replacement data contains null characters",
	"cannot embed slash, newline, or null in a directory name",
	"destination file already exists",
	"cannot rename file to %s",
	"cannot embed nulls in an input field",
	"cannot embed newlines in an input field",
	"no input fields present",
	"no links present",
	"no buttons present",
	"multiple input fields present, please use %c1 through %c%d",
	"multiple links present, please use %c1 through %c%d",
	"multiple buttons present, please use %c1 through %c%d",
	"could not read the data from the server",
	"%s is not a url",
	"download complete",
	"cannot identify %s on the network",
	"the %s protocol is not supported by edbrowse, and is not included in the mime types in your config file",
	"warning: could not preload <buffer %d> with its initial text\n",
	"download in progress",
	"cannot connect to %s",
	"download: ",
	"The certificate for host %s could not be verified - SSL connection aborted",
	"new text added at line %d\n",
	"?\tprint this help message.\nq\tquit this program.\nspace\tread more of this mail message.\nn\tmove on to the next mail message.\nd\tdelete this message.\nw\twrite this message to a file.\nW\twrite this message to a file and delete it.\nu\twrite this message unformatted to a file.\nU\twrite this message unformatted to a file and delete it.\na\tscan and save attachments.\ns\tstop reading mail from this folder.",
	"web page requires authorization",
	"login aborted",
	"?: print this help message.\nq: quit this program.\ng name|#: go to folder.\nl: list folders with unread email.\na: list all folders.\nc name: create a new folder.\nd name|#: delete folder.",
	"cannot write to temp file %s to uncompress the web page",
	"download in foreground",
	"download in background",
	"complete",
	"failed",
	"ftp could not connect to remote host",
	"ftp could not connect to remote host (timed out)",
	"ftp transfer failed",
	"ftp transfer failed (timed out)",
	"in progress",
	"stop",
	"ftp malformed url",
	"no attachments",
	0,
	0,
	"ftp session initialization failed",
	0,
	"edbrowse was not compiled with database access",
	"missing alias in address book line %d",
	"missing : in address book line %d",
	"alias in address book line %d is too long, limit 15 characters",
	"email in address book line %d is too long, limit 63 characters",
	" email in address book line %d does not have an @",
	"cannot handle whitespace in email, address book line %d",
	"unprintable characters in your alias or email, address book line %d",
	"last line of your address book is not terminated",
	0,
	0,
	0,
	0,
	0,
	"warning: form url specifies a section %s, which will be ignored\n",
	"file %s is empty",
	"your email should begin with subject:",
	0,
	"subject line too long, limit %d characters",
	0,
	".signature is not a regular file",
	"cannot access .signature file",
	"cannot mail the binary file %s, perhaps this should be an attachment?",
	"either none or all of the attachments must be declared \"alternative\"",
	"too many recipients, limit %d",
	"No address book specified, please check your .ebrc config file",
	"alias %s not found in your address book",
	"no recipients specified",
	"session %d is empty, cannot atach",
	"cannot access attachment %s",
	"file %s is not a regular file, cannot attach",
	"file %s is empty, cannot attach",
	0,
	0,
	"mail server rejected %s",
	0,
	0,
	"no mail accounts specified, plese check your config file",
	"invalid account number %d, please use 1 through %d",
	"cannot send mail while in browse mode",
	"cannot send mail while in database mode",
	"cannot send mail from directory mode",
	"cannot mail binary data, should this be an attachment?",
	"cannot mail an empty file",
	"no recipient at line %d",
	"cannot cc or bcc to the first recipient",
	"no attachment at line %d",
	"invalid account number at line %d",
	0,
	"line %d should begin with to: attach: alt: account: or subject:",
	0,
	"no recipients specified, place to: emailaddress at the top of youre file",
	"%s:// expected",
	"unrecognized protocol %s",
	"invalid :port specifier at the end of the domain",
	"domain name too long",
	"user name too long",
	"password too long",
	0,
	0,
	"no function specified",
	"function name should only contain letters and numbers",
	"no such function %s",
	"too many arguments",
	"~%d has no corresponding argument",
	"could not spawn subcommand %s, errno %d",
	"could not create temp file %s, errno %d",
	"too many sql tables in cache, limit %d",
	"%s is not a regular file",
	0,
	"cannot read the contents of %s",
	"cannot access %s",
	"undefined environment variable",
	"cannot expand * ? or [] prior to the last /",
	"%s is not an accessible directory",
	"shell pattern is too long",
	"sorry, I don't know how to expand filenames with \\ in them",
	"improperly formed [] pattern",
	"error compiling the shell pattern, %s",
	"unexpected error while evaluating the shell pattern",
	"shell pattern does not match any files",
	"shell pattern matches more than one file",
	"line becomes too long when shell variables are expanded",
	"the config file does not specify the database - cannot connect",
	"cannot connect to the database - error %d",
	"database error %d",
	"no primary key for this table",
	"column name %s is too long, limit %d characters",
	"syntax error in where clause",
	"column %d is out of range",
	"multiple columns match %s",
	"no column matches %s",
	"no such table %s",
	"invalid column name",
	"cannot select more than one blob column",
	"the data contains pipes, which is my reserved delimiter",
	"the data contains newlines",
	"line contains too many fields, please do not introduce any pipes into the text",
	"line contains too few fields, please do not remove any pipes from the text",
	"no primary key column for this table",
	"miscelaneous sql error %d",
	"cannot delete more than 100 rows at a time",
	"cannot change a key column",
	"cannot change a blob field",
	"cannot change a text field",
	"oops!  I deleted %d row(s), and %d database record(s) were affected.",
	"oops!  I inserted %d row(s), and %d database record(s) were affected.",
	"oops!  I updated %d row(s), and %d database record(s) were affected.",
	"some other row in the database depends on this row",
	"row or table is locked",
	"you do not have permission to modify the database in this way",
	"deadlock detected",
	"placing null into a not-null column",
	"check constraint violated",
	"database timeout",
	"cannot modify a view",
	"no closing %s",
	"warning, javascript cannot be invoked through keystroke events",
	"javascript cannot be invoked through focus or blur",
	"onchange handler is not accessible",
	"%s is not part of a fill-out form",
	"%s does not have a name",
	"unrecognized method, plese use GET or POST",
	"unrecognized enctype, plese use multipart/form-data or application/x-www-form-urlencoded",
	"form cannot submit using protocol %s",
	"unrecognized input type %s",
	"multiple radio buttons have been selected",
	"%s is closed inside %s",
	"%s begins in the middle of %s",
	"an unexpected closure of %s, which was never opened",
	"a text area begins in the middle of a text area",
	"%s appears inside an anchor",
	"%s contains html tags",
	"option cannot contain a comma when it is part of a multiple select",
	"empty option",
	"multiple titles",
	"%s is not inside a list",
	"%s is not inside a table",
	"%s is not inside a table row",
	"option appears outside a select statement",
	"multiple options are selected",
	"unprocessed tag action %d",
	"%s is not closed at eof",
	"java is opening a blank window",
	"unexpected characters after the encoded attachment",
	"invalid characters in the encoded attachment",
	"onchange handler does not work with textarea",
	"warning, javascript cannot be invoked by a double click",
	"error resolving option %s during sync or form submit",
	"tag cannot have onunload and onclik handlers simultaneously",
	"script is not closed at eof, suspending javascript",
	"could not fetch local javascript, %s",
	"could not fetch javascript from %s, code %ld",
	"could not fetch javascript, %s",
	"javascript disabled, skipping the onclick code",
	"javascript disabled, skipping the onchange code",
	"javascript disabled, skipping the onreset code",
	"javascript disabled, skipping the onsubmit code",
	"could not find the html tag associated with the javascript variable being modified",
	"javascript modified a textarea, and that isn't implemented yet",
	"warning: garbled refresh directive, %s\n",
	0,
	"warning: http redirection %ld, but a new url is not specified\n",
	"warning: http error %ld, %s\n",
	0,
	"warning: cannot update config file",
	"help messages on",
	"ftp download: ",
	"no ssl certificate file specified; secure connections cannot be verified",
	"could not rewrite your config file; your configuration data may be lost!",
	".ebrc: null characters at line %d",
	".ebrc: missing function name at line %d",
	".ebrc: function name at line %d begins with a digit",
	".ebrc: function name at line %d is too long, limit ten characters",
	".ebrc: improper function definition syntax at line %d",
	".ebrc: line %d, \"condition > file\" expected",
	".ebrc: line %d, filter rule has no match string",
	".ebrc: line %d, match on %s is set nowhere",
	".ebrc: line %d, too many mail filters",
	".ebrc: unrecognized keyword %s at line %d",
	".ebrc: line %d, attribute %s canot be set outside of a mail descriptor",
	".ebrc: line %d, attribute %s canot be set outside of a mime descriptor",
	".ebrc: line %d, attribute %s canot be set outside of a table descriptor",
	".ebrc: line %d, attribute %s canot be set inside a mail descriptor or filter block",
	".ebrc: line %d, attribute %s canot be set inside a mime descriptor",
	".ebrc: line %d, attribute %s canot be set inside a table descriptor",
	".ebrc: line %d, attribute %s is set to nothing",
	".ebrc: line %d, too many columns, limit %d",
	".ebrc: line %d, keycol should be number or number,number",
	".ebrc: line %d, keycol is out of range; only %d columns specified",
	".ebrc: address book %s is not a regular file",
	0,
	".ebrc: %s is not a directory",
	".ebrc: line %d, too many user agents, limit 9",
	".ebrc: cookie jar %s is not a regular file",
	".ebrc: cannot create cookie jar %s",
	".ebrc: too many no js directives, limit %d",
	".ebrc: line %d, domain %s does not contain a dot",
	".ebrc: mail trash can %s is not a regular file",
	".ebrc: SSL certificate file %s is not a regular file",
	".ebrc: SSL certificate file %s does not exist or is not readable.",
	".ebrc: line %d, keyword %s is not yet implemented",
	".ebrc: setting multiple mail accounts as default",
	".ebrc: missing inserver at line %d",
	".ebrc: missing outserver at line %d",
	".ebrc: missing login at line %d",
	".ebrc: missing password at line %d",
	".ebrc: missing from at line %d",
	".ebrc: missing reply at line %d",
	".ebrc: missing type at line %d",
	".ebrc: missing description at line %d",
	".ebrc: missing suffix or protocol list at line %d",
	".ebrc: missing program at line %d",
	".ebrc: missing table name at line %d",
	".ebrc: missing short name at line %d",
	".ebrc: missing columns at line %d",
	".ebrc: unexpected } at line %d",
	".ebrc: else at line %d is not part of an if statement",
	".ebrc: garbled text at line %d",
	".ebrc: line %d, cannot start a function, mail/mime descriptor, or filter block inside %s",
	".ebrc: statement at line %d must appear inside a function",
	"too many email accounts in your .ebrc config file, limit %d",
	"too many mime types in your .ebrc config file, limit %d",
	"too many sql tables in your .ebrc config file, limit %d",
	"too many functions in your .ebrc config file, limit %d",
	".ebrc: line %d, control structures are nested too deeply",
	".ebrc: function %s is not closed at eof",
	".ebrc: mail or mime block is not closed at EOF",
	"home directory not defined by $HOME.",
	"%s is not a directory",
	"no mail accounts specified, please check your .ebrc config file",
	"invalid account number, please use 1 through %d",
	"edbrowse  -v    (show version)\nedbrowse -h (this message)\nedbrowse -c (edit config file)\nedbrowse [-e] [-d#] -f[#] (fetch mail) \nedbrowse  [-e] [-d#] -[p]m    (read pending mail)\nedbrowse  [-e] [-d#] -[p]fm[#]    (fetch mail and read pending mail)\nedbrowse  [-e] [-d#] -m[#] address1 address2 ... file [+attachments]\nedbrowse  [-e] [-d#] file1 file2 ...",
	"please specify at least one recipient and the file to send",
	"please specify at least one recipient and the file to send, before your attachments",
	"too many files open simultaneously, limit %d",
	"invalid session %d in fetchLineContext()",
	"invalid line number %d in fetchLineContext()",
	"too many proxy entries in your .ebrc config file, limit %d",
	"session %d out of range in cxActive",
	"double init on session %d",
	"quitting a nonactive session %d",
	"empty new piece in addToMap()",
	"no newline on directory entry %s",
	"no closing > at line %d",
	"fieldInBuffer could not find tag %d newtext %s",
	"cannot rebuild your cookie jar %s",
	0,
	"fetchmail client is interactive, and cannot run in the background",
	"mailbox directory not specified in your .ebrc file",
	"Cannot change directory to %s",
	0,
	"Invalid login or password",
	0,
	0,
	0,
	0,
	0,
	"tag code %d has bad character %c following",
	0,
	"htmlParse() is not reentrant.",
	"unexpected input type in submitForm()",
	"list = 0 in tagFromJavaVar()",
	0,
	"Could not allocate memory for javascript operations.",
	"Unable to create javascript context.",
	"Unable to create javascript window object.",
	"Unable to create standard classes for javascript.",
	"Unable to create document object for javascript.",
	"hostname:port is too long",
	"protocol: is too long",
	"error allocating %zu bytes",
	"error callocating %zu bytes",
	"reallocMem(p,0)",
	"reallocMem(0,%zu)",
	"error re-allocating %zu bytes",
	"stringInList(null,...)",
	"stringInListCI(null,...)",
	"charInList(null,...)",
	"null pointer in pstLength",
	"canot use ioctl() to manage the tty",
	"cannot open %s",
	"cannot create or write to %s",
	"calling fopen() with invalid mode %s",
	"misplaced / in getDirURL(%s)",
	"misplaced / in %s",
	"decodePostData(0,0)",
	"cannot convert pdf to html; make sure pdftohtml is installed, and try running it on %s",
	0,
	0,
	"cannot reply in directory mode",
	"cannot reply in database mode",
	"cannot reply to an empty file",
	"cannot reply to a binary file",
	"subject and reply lines are required",
	"warning, there is no message ID to reference",
	"Sorry, email headers are not available.\nYou must start with an unformatted email message, browse, then reply all.",
	"l expands control chars into hex",
	"l expands control and nonascii chars into hex",
	"Warning: search/substitution functions will not support utf8 characters,\nbecause your pcre library lacks this functionality.\nexport PCREUTF8=off to disable this feature and suppress this warning message.",
	"converting to iso8859",
	"converting to utf8",
	"do not convert between iso8859 and utf8",
	"automatically convert between iso8859 and utf8",
	"cannot copy a directory tree to your trash bin on another file system;\nuse cpio -p or cp -r from the shell",
	"cannot delete a directory tree; use rm -r from the shell",
	"Failed to initialize libcurl.",
	"This ftp directory listing is empty.",
	"search and substitute using ascii",
	"search and substitute using utf8",
	"Warning: you may need to (temporarily) disable utf8 search and substitute\nwith the su8 command for this to work properly.",
	"primary key comprises more than 3 columns",
	"cannot determine the next value for the serial key(0)",
	"Table names are in buffer %d\n",
	"no datasource specified",
	"connecting to datasource %s\n",
	"row",
	"rows",
	"selected",
	"inserted",
	"updated",
	"deleted",
	"procedure executed",
	"table",
	"sql statement is not terminated by a final semicolon, or a right bracket on the following line",
	"update or delete statement with no where clause",
	"remote access denied",
	"Authorization required to access %s",
	"operation failed because memory could not be allocated",
	"Your version of libcurl is older than version %u.%u.%u.\nYou must upgrade libcurl in order to use edbrowse.",
	"operation timed out",
	"cannot send data to the server",
	"the curl library returned the following error message while performing the requested operation: %s",
	"foreign keys for %s\n",
	"do not fetch blob columns",
	"fetch blob columns",
	"SSL connect error in libcurl: %s",
	"input tty",
	"input readline()",
	0,
	"Unrecoverable JavaScript error in this session, javascript is closed.",
	"onclick handler is not accessible",
	"Unable to parse data URI containing JavaScript",
};

/* Translation by Erwin Bliesenick: erwinb@no-log.org */
static const char *frenchMessages[] = {
	"EOF - fin de fichier",
	"pas de fichier",
	"rien",
	"substitutions globales",
	"substitutions locales",
	"insensible à la casse",
	"sensible à la casse",
	"répertoires en lecture seule",
	"répertoires en lecture écriture",
	"répertoires en lecture écriture avec effacement",
	"pas de redirection http",
	"redirection http",
	"ne pas envoyer le référent",
	"envoyer le référent",
	"javascript dédactivé",
	"javascript activé",
	"binaire traité comme texte",
	"détection des fichiers binaires",
	"mode passif",
	"mode actif",
	"Panne du moteur javascript : toutes les sessions javascript ouvertes ont été fermées.",
	"pas de vérification des connexions ssl (moins sûr)",
	"vérification des connexions ssl",
	"ne pas afficher les fichiers cachés en mode répertoire",
	"afficher les fichiers cachés en mode répertoire",
	"Impossible de lancer un sous-processus pour edbrowse-js : javascript a été désactivé.",
	"Impossible de lancer edbrowse-js : javascript a été désactivé.",
	"marqueurs de fin de ligne désactivés",
	"marqueurs de fin de ligne activés pour les lignes listées",
	"marqueurs de fin de ligne activés",
	"javascript désactivé, aucune action lancée",
	"javascript désactivé, on va directement à l'url",
	"redirection interrompue par l'utilisateur",
	"vide",
	"nouvelle session",
	"pas de saut de ligne à la fin",
	"mode répertoire",
	"données binaires",
	"ok",
	" [binaire]",
	"pas de titre",
	"pas de description",
	"pas de mots-clés",
	"session %d\n",
	"Envoi de courrier. Tapez votre courrier, tapez sm pour l'envoyer, puis ^ pour revenir.",
	"la ligne %d a été modifiée\n",
	"pas de sujet",
	"pas de fichier de configuration",
	"pas de bloc subjfilter{...} dans le fichier de configuration .ebrc",
	"interruption, tapez qt pour quitter complètement",
	"edbrowse prêt",
	"la ligne de commande contient des caractères nuls; vous pouvez utiliser \\0 dans une chaîne de recherche/remplacement pour indiquer le caractère nul",
	"autorisation nécessaire - tapez x pour annuler.",
	"trop de redirections",
	"succès",
	"répertoire",
	"redirection vers %s retardée de %d secondes\n",
	"Nom d'utilisateur: ",
	"nom d'utilisateur trop long, la limite est de %d caractères",
	"Mot de passe: ",
	"nom de passe trop long, la limite est de %d caractères",
	"Impossible de communiquer avec edbrowse-js : javascript a été désactivé.",
	"attention, répertoire inaccessible - la liste des fichiers sera vide",
	"désastre, message d'erreur %d trop long\n",
	"ligne %d: ",
	"erreur de navigation: ",
	"le tampon %d a été mis à jour\n",
	"pas d'options",
	"formulaire réinitialisé",
	"formulaire en cours de soumission",
	"Une nouvelle fenêtre a été créée dans le tampon %d\n",
	" beaucoup",
	" recommendé",
	"]",
	"aucune option ne contient la chaîne %s\n",
	"envoi du courrier à %s\n",
	"Envoi effectué; attendez une réponse par retour de courrier.",
	"indésirable",
	"quitter",
	"suivant",
	"effacement",
	"ip effacé",
	"l'option -p désactive cette fonctionnalité",
	"Environnement de travail javascript impossible à construire : javascript a été désactivé.",
	"fin du message",
	"pas encore implémenté",
	"nom de fichier: ",
	"Désolé, le fichier %s existe déjà.\n",
	"abrégé ",
	"pièce jointe vide",
	"pièce jointe ",
	"plus de tampon disponible, pièce jointe ignorée",
	"impossible de copier la pièce jointe dans le tampon %d",
	"impossible de créer le fichier %s, pièce jointe ignorée\n",
	"impossible de sauvegarder le fichier %s, pièce jointe ignorée\n",
	"pas de courrier",
	"%d messages\n",
	"Messages d'interprocessus javascript désynchronisés.",
	" from ",
	"?\taffiche ce message d'aide.\nq\tquitte ce programme.\nx\tquitte sans rien modifier sur le serveur de courrier.\nespace\tcontinuer la lecture de ce message.\nn\taller au message suivant.\nd\teffacer ce message.\nw\tsauvegarder ce message et l'effacer.\nu\tsauvegader ce message non formaté puis l'effacer.",
	"création du fichier %s impossible\n",
	"sauvegarde du fichier %s impossible\n",
	"courrier sauvegardé, %d octets",
	" ajouté",
	"page terminée, utilisez la touche retour arrière ou quittez",
	"Désolé, innerText n'est pas encore implémenté",
	"pas d'erreurs",
	"authentification proxy pour une url non-proxy",
	"session %d non active",
	"session 0 invalide",
	"débordement de la session %d, la limite est de %d",
	"vous êtes déjà dans la session %d",
	"`w' attendu",
	"`w' attendu en session %d",
	"Vous avez atteint la limite d'170 million de lignes.\nSauvegardez vos fichiers, puis sortez et redémarrez le programme.",
	"chemin du répertoire trop long, la limite est de %d caractères",
	"répertoires en lecture seule, tapez dw pour autoriser l'écriture",
	"impossible de créer le fichier corbeille .Trash, pour contenir vos fichiers effacés",
	"effacement du fichier %s impossible",
	"impossible de mettre %s à la corbeille, passez en mode dx pour l'effacer",
	"destination à l'intérieur du bloc à déplacer ou à copier",
	"pas de modification",
	"ne peut fusionner une seule ligne",
	"impossible de lire la base de données dans un autre fichier",
	"impossible de lire plusieurs tables dans la même session",
	"nom de fichier absent",
	"nom de domaine vide dans l'url",
	"impossible d'écrire sur une url",
	"impossible d'écrire dans une table de base de données",
	"impossible de sauvegarder un fichier vide",
	"impossible de créer %s",
	"ne peut écrire dans %s",
	"session non interactive",
	"ligne %c trop grande",
	"une commande shell ne peut contenir des caractères nuls",
	"label %c non défini",
	"délimiteur invalide",
	"chaîne de recherche non conservée",
	"chaîne de remplacement non conservée",
	"expression régulière trop grande",
	"ligne terminée par un anti-slash",
	"parenthèse fermante inattendue",
	"on ne peut remplacer que de $1 à $9",
	"le modificateur %s n'est précédé d'aucun caractère",
	"pas de crochet fermant",
	"pas de parenthèse fermante",
	"tampon vide",
	"erreur dans l'expression régulière, %s",
	"erreur inattendue en évaluant l'expression régulière %d",
	"chaîne de recherche non trouvée",
	"numéro de ligne trop grand",
	"numéro de ligne négatif",
	"pas d'expression régulière après %c",
	"délimiteur absent",
	"aucune ligne ne correspond au modèle g",
	"toutes les lignes correspondent au modèle v",
	"aucune des lignes marquées n'a pu être modifiée avec succès",
	"opération interrompue",
	"pas de correspondance",
	"Objets javascript manquants ou mal configurés.",
	"l'agent numéro %c n'est pas défini",
	"impossible d'afficher le nouveau répertoire",
	"impossible d'établir le répertoire courant",
	"répertoire invalide",
	"lecture audio impossible à partir d'un tampon vide audio",
	"lecture audio impossible en mode navigation",
	"lecture audio impossible en mode répertoire",
	"lecture audio impossible en mode base de données",
	"le fichier n'a pas d'extension, utilisez mt.xxx pour définir votre propre extension",
	"extension limitée à 5 caractères",
	"l'extension .%s n'est pas un type mime connu, vérifiez votre fichier de configuration.",
	"pas de nom de fichier ou d'url à réafficher",
	"pas en mode base de données",
	"pas en mode navigation",
	"le nom de fichier ne contient pas le caractère /",
	"le nom de fichier se termine par le caractère /",
	"commande sm suivie de caractères invalides",
	"vous devez spécifier exactement un %s après la commande B",
	"la ligne ne contient pas de %c ouvrant(e)",
	"%c et %c non équilibrés sur cette ligne, essayez B%c ou B%c",
	"la ligne ne contient pas de parenthèses, de crochets ou d'accolades non équilibrés",
	"ne peux trouver de ligne équilibrant %c",
	"session %d actuellement en mode navigation",
	"session %d actuellement en mode répertoire",
	"pas de nom de fichier",
	"fin du tampon",
	"plus de lignes à fusionner",
	"mauvais intervalle",
	"impossible de découper les lignes en mode répertoire",
	"impossible de découper les lignes en mode base de données",
	"impossible de découper les lignes en mode navigation",
	"commande %c inconnue",
	"%c impossible en mode répertoire",
	"%c impossible en mode base de données",
	"%c impossible en mode navigation",
	"ligne numéro zéro",
	"pas d'espace après la commande",
	"la commande %c ne peut s'appliquer globalement",
	"destination du déplacement ou de la copie invalide",
	"texte inattendu après la commande %c",
	"rien à défaire",
	"tapez svp k[a-z]",
	"impossible d'étiqueter un intervalle entier",
	"ne peux sauvegarder 0",
	"attention : pas de tampon pour gérer la fenêtre auxiliaire",
	"texte inattendu après la commande q",
	"impossible de renommer le répertoire",
	"impossible de renommer la table",
	"impossible d'ajouter à un autre tampon",
	"pas de fichier spécifié",
	"ne peut mettre à jour le répertoire; les fichiers seront modifiés quand vous quitterez",
	"ne peut mettre à jour la base de données; les lignes seront modifiées quand vous quitterez",
	"texte inattendu après la commande ^",
	"pas de texte antérieur",
	"texte inattendu après la commande M",
	"destination de la session non spécifiée",
	"pas de texte antérieur, sauvegarde impossible",
	"impossible d'appliquer la commande g à un intervalle",
	"g impossible en mode base de données",
	"impossible d'appliquer la commande i%c à un intervalle",
	"impossible d'utiliser i< dans une commande globale",
	"le tampon %d est vide",
	"le tampon %d contient plus d'une ligne",
	"impossible d'ouvrir %s",
	"impossible de lire %s",
	"le texte entré contient des caractères nuls",
	"il y a un retour-chariot dans la ligne",
	"le première ligne de %s est trop longue",
	"le fichier est actuellement dans le tampon - utilisez la commande rf pour le réafficher",
	"navigation impossible dans un fichier binaire",
	"navigation impossible dans un fichier vide",
	"ce contenu ne semble pas navigable",
	"en cours de navigation",
	"label %s non trouvé",
	"i impossible en mode navigation",
	"impossible de lancer une commande d'insertion à partir d'une fonction d'edbrowse",
	"Communication avec javascript impossible : javascript est fermé.",
	"commande %c non implémentée",
	"%d hors limites",
	"aucune option ne contient la chaîne %s",
	"de multiples options contiennent la chaîne %s",
	"c'est un bouton; tapez i* pour le déclencher",
	"c'est un bouton de validation; tapez i* pour le déclencher",
	"c'est un bouton d'annulation; tapez i* pour le déclencher",
	"c'est une zone de texte, vous devez l'éditer dans la session %d",
	"champ en lecture seule",
	"une zone de saisie ne peut contenir un saut de ligne",
	"saisie trop long, la limite est de %d caractères",
	"le champ doit être défini + or -",
	"vous ne pouvez réinitialiser un bouton radio; vous devez en activer un autre",
	"%s n'est pas un fichier accessible",
	"nombre attendu",
	"la session %d contient des caractères nuls",
	"l'envoi d'un fichier exige 'method=post and enctype=multipart/form-data'",
	"c'est une zone de saisie, pas un bouton",
	"ce bouton ne fait pas partie d'un formulaire",
	"pas de javascript associé à ce bouton",
	"le formulaire n'inclut aucune URL de destination",
	"l'action de ce formulaire ne renvoie pas à une destination URL",
	"javascript désactivé, impossible d'activer ce formulaire",
	"Le formulaire est passé du mode https au mode http, il n'est plus sécurisé",
	"impossible de soumettre avec le protocole %s",
	"%d hors limites, utilisez s'il vous plait %c1 à %c%d",
	"%d hors limites, utilisez s'il vous plait  %c1, ou simplement %c",
	"impossible de remplacer plusieurs fois la chaîne vide",
	"téléchargement abandonné.",
	"pas d'expression régulière après %c",
	"nombres multiples après le troisième délimiteur",
	"suffixe de substitution inattendu après le troisième délimiteur",
	"impossible d'utiliser simultanément un suffixe numérique et le suffixe `g'",
	"désolé, impossible d'exécuter la commande bl sur les lignes excédant %d caractères",
	"les données de remplacement contiennent des sauts de ligne",
	"les données de remplacement contiennent des caractères nuls",
	"un nom de répertoire ne peut contenir un slash, un saut de ligne ou un caractère nul",
	"le fichier destination existe déjà",
	"impossible de renommer le fichier à %s",
	"une zone de saisie ne peut contenir des caractères nuls",
	"une zone de saisie ne peut contenir des sauts de ligne",
	"aucune zone de saisie présente",
	"aucun lien présent",
	"aucun bouton présent",
	"il y a plusieurs zones de saisie, utilisez svp %c1 à %c%d",
	"il y a plusieurs liens, utilisez svp %c1 à %c%d",
	"il y a plusieurs boutons, utilisez svp %c1 à %c%d",
	"impossible de lire les données sur le serveur",
	"%s n'est pas une url",
	"téléchargement terminé",
	"impossible d'identifier %s sur le réseau",
	"le protocole %s n'est pas supporté par edbrowse, et n'est pas défini dans les types mime de votre fichier de configuration",
	"attention : impossible de précharger le texte initial dans le <tampon %d>\n",
	"télachargement en cours",
	"connexion impossible à %s",
	"téléchargement: ",
	"Le certificat de sécurité de l'hôte %s ne peut être vérifié - connexion SSL abandonnée",
	"nouveau texte ajouté à la ligne %d\n",
	"?\taffiche ce texte d'aide.\nq\tquitter ce programme.\nespace\taffiche la suite de ce courriel.\nn\tva au courriel suivant.\nd\tefface ce message.\nw\tsauvegarde ce message dans un fichier.\nW\tsauvegarde ce message dans un fichier puis l'efface.\nu\tsauvegarde ce message non formaté dans un fichier.\nU\tsauvegarde ce message dans un fichier puis l'efface.\na\tparcourt et sauvegarde les pièces attachées.\ns\tinterrompre la lecture des courriels de ce dossier.",
	"la page web requiert une autorisation",
	"authentification abandonnée",
	"?: affiche ce message d'aide.\nq: quitter ce programme.\ng name|#: aller au répertoire.\nl: affiche les répertoires contenant des courriels non lus.\na: affiche tous les répertoires.\nc nom: crée un nouveau répertoire.\nd nom|#: efface le répertoire.",
	"impossible d'écrire dans le fichier temporaire %s pour décompresser la page web",
	"téléchargement au premier plan",
	"téléchargement en arrière plan",
	"terminée",
	"échec",
	"connexion ftp impossible à l'hôte distant",
	"connexion ftp impossible à l'hôte distant (délai dépassé)",
	"échec du transfert ftp",
	"échec du transfert ftp (délai dépassé)",
	"active",
	"stop",
	"ftp : url mal formée",
	"pas de pièces attachées",
	0,
	0,
	"ftp : échec de la session d'initialisation",
	0,
	"edbrowse n'a pas été compilé avec l'accès aux bases de données",
	"alias manquant dans le carnet d'adresses à la ligne %d",
	"manquant dans le carnet d'adresses à la ligne %d",
	"alias trop long dans le carnet d'adresses, limite 15 caractères",
	"email trop long dans le carnet d'adresses, limite 63 caractères",
	" pas de @ dans l'email à la ligne %d du carnet d'adresses",
	"espaces interdits dans un email, à la ligne %d du carnet d'adresses",
	"caractères non imprimables dans un alias ou un email, à la ligne %d du carnet d'adresses",
	"la dernière ligne de votre carnet d'adresses n'est pas terminée",
	0,
	0,
	0,
	0,
	0,
	"attention : le formulaire url spécifie une section %s, qui sera ignorée\n",
	"le fichier %s est vide",
	"votre mail devrait commencer par 'subject:':",
	0,
	"ligne sujet trop longue, la limite est de %d caractères",
	0,
	".signature n'est pas un fichier régulier",
	"impossible d'accéder au fichier .signature",
	"impossible d'envoyer le fichier binaire %s, serait-ce une pièce jointe ?",
	"aucune ou bien toutes les pièces jointes doivent être spécifiées \"alternative\"",
	"trop de destinataires, la limite est de %d",
	"Pas de carnet d'adresses défini, contrôlez votre fichier de configuration .ebrc",
	"impossible de trouver l'alias %s dans votre carnet d'adresses",
	"aucun destinataire spécifié",
	"la session %d est vide, impossible de joindre quelque chose",
	"impossible d'accéder à la pièce jointe %s",
	"impossible de joindre le fichier %s, ce n'est pas un fichier régulier",
	"le fichier %s est vide, impossible de le joindre",
	0,
	0,
	"le serveur de courrier a rejeté %s",
	0,
	0,
	"pas de comptes de courrier définis, contrôlez votre fichier de configuration",
	"numéro de compte de courrier invalide %d, utilisez 1 à %d",
	"impossible d'envoyer du courrier en mode navigation",
	"impossible d'envoyer du courrier en mode base de données",
	"impossible d'envoyer du courrier en mode répertoire",
	"impossible d'envoyer des données binaires, serait-ce une pièce jointe ?",
	"impossible d'envoyer un fichier vide",
	"pas de destinataire à la ligne %d",
	"impossible de mettre le premier destinataire en cc ou bcc",
	"pas de pièce jointe à la ligne %d",
	"numéro de compte de courrier invalide à la ligne %d",
	0,
	"la ligne %d devrait débuter par to: attach: alt: account: ou subject:",
	0,
	"pas de destinataires spécifiés, placez to: adresse email au début de votre fichier",
	"%s:// attendu",
	"protocole %s non reconnu",
	":port invalide à la fin du nom de domaine",
	"nom de domaine trop long",
	"nom d'utilisateur trop long",
	"mot de passe trop long",
	0,
	0,
	"pas de fonction spécifiée",
	"les noms de fonction ne peuvent contenir que des lettres et des chiffres",
	"fonction %s non trouvée",
	"trop d'arguments",
	"~%d n'a pas d'argument correspondant",
	"impossible de créer la sous-commande %s, erreur numéro %d",
	"impossible de créer le fichier temporaire %s, erreur numéro %d",
	"trop de tables sql dans le cache, la limite est de %d",
	"%s n'est pas un fichier régulier",
	0,
	"impossible de lire le contenu de %s",
	"impossible d'accéder à %s",
	"variable d'environnement n'est pas définie",
	"impossible de développer * ? ou [] antérieur au dernier /",
	"%s n'est pas un répertoire accessible",
	"modèle shell trop long",
	"désolé, j'ignore comment développer les noms de fichiers contenant \\",
	"modèle [] mal formé",
	"erreur de compilation du modèle shell, %s",
	"erreur inattendue d'évaluation du modèle shell",
	"le modèle shell ne correspond à aucun nom de fichier",
	"le modèle shell correspond à plusieurs noms de fichier",
	"ligne trop longue après expansion des variables shell",
	"le fichier de config ne définit aucune base de données - connexion impossible",
	"connexion à la base de données impossible - erreur %d",
	"erreur sql inattendue %d",
	"pas de colonne index spécifiée",
	"nom de colonne %s trop long, la limite est de %d caractères",
	"erreur de syntaxe dans la clause where",
	"débordement dans la colonne %d",
	"plusieurs colonnes correspondent à %s",
	"aucune colonne ne correspond à %s",
	"la table %s n'existe pas",
	"nom de colonne invalide",
	"impossible de sélectionner plus d'une colonne contenant des données binaires",
	"les données contiennent le caractère pipe, réservé comme délimiteur de champ",
	"les données contiennent des sauts de ligne",
	"trop de champs dans la ligne, s'il vous plait, ne mettez pas de caractères pipe dans le texte",
	"pas assez de champs dans la ligne, s'il vous plait, ne supprimez pas de caractères pipe dans le texte",
	"colonne index non spécifiée",
	"erreur sql %d",
	"impossible de supprimer plus de 100 lignes à la fois",
	"impossible de modifier une colonne index",
	"impossible de modifier un champ de données binaires",
	"impossible de modifier un champ de texte",
	"oups!  j'ai supprimé %d ligne(s), et %d enregistrement(s) de la base de données ont été affectés.",
	"oups!  j'ai supprimé %d ligne(s), et %d enregistrement(s) de la base de données ont été affectés.",
	"oups!  j'ai supprimé %d ligne(s), et %d enregistrement(s) de la base de données ont été affectés.",
	"d'autres lignes de la base de données dépendent de cette ligne",
	"la ligne ou la table sont verrouillées",
	"vous n'avez pas la permission de modifier la base de données par ce moyen",
	"deadlock (verrou mortel) détecté",
	"placement d'un null dans une colonne non null",
	"violation de contrainte",
	"dépassement de délai de la base de données",
	"impossible de modifier une vue",
	"pas de fermeture de %s",
	"attention, javascript ne peut être invoqué par un événement clavier",
	"javascript ne peut être invoqué par un focus ou un blur",
	"gestionnaire onchange inaccessible",
	"%s n'appartient pas à un formulaire",
	"%s n'a pas de nom",
	"méthode inconnue, utilisez s'il vous plaît GET ou POST",
	"codage enctype non reconnu, utilisez s'il vous plaît multipart/form-data or application/x-www-form-urlencoded",
	"le formulaire ne peut être soumis en utilisant le protocole %s",
	"saisie de type inconnu %s",
	"plusieurs boutons radio ont été activés",
	"%s est inclus dans %s",
	"%s débute au milieu de %s",
	"fermeture inattendue de %s, qui n'a jamais été ouvert",
	"une zone de texte débute au milieu d'une zone de texte",
	"%s apparaît dans une ancre",
	"%s contient des balises html",
	"l'option ne peut contenir une virgule lorsqu'elle fait partie d'une sélection multiple",
	"option vide",
	"titres multiples",
	"%s n'est pas dans une liste",
	"%s n'est pas dans une table",
	"%s n'est pas dans une ligne de la table",
	"option apparaît à l'extérieur d'un ordre select",
	"de multiples options sont sélectionnées",
	"commande %d du tag non traitée",
	"%s non fermé à la fin du fichier",
	"java ouvre une fenêtre vide",
	"caractères inattendus après la pièce jointe encodée",
	"caractères invalides dans la pièce jointe encodée",
	"le gestionnaire handler ne fonctionne pas avec les zones de texte",
	"attention, javascript ne peut être invoqué par un double clic",
	"erreur de détermination de l'option %s pendant la synchronisation ou la soumission du formulaire",
	"une balise ne peut simultanément gérer onunload and onclik",
	"le script n'est pas clos en fin de fichier, javascript est suspendu",
	"impossible de charger localement javascript, %s",
	"impossible de charger javascript depuis %s, code %ld",
	"impossible de charger javascript, %s",
	"javascript désactivé, code onclick ignoré",
	"javascript désactivé, code onchange ignoré",
	"javascript désactivé, code onreset ignoré",
	"javascript désactivé, code onsubmit ignoré",
	"impossible de trouver la balise html associée à la variable javascript modifiée",
	"javascript a modifié une zone de texte, et ce n'est pas encore implémenté",
	"attention : directive de rafraîchissement altérée, %s\n",
	0,
	"attention: redirection http %ld, mais la nouvelle url n'a pas été spécifiée\n",
	"attention : erreur html %ld, %s\n",
	0,
	"attention : impossible de modifier le fichier de configuration",
	"messages d'aide activés",
	"téléchargement ftp: ",
	"pas de fichier de certificats ssl; les connexions sécurisées ne pourront être vérifiées",
	"Impossible de ré-écrire votre fichier de configuration : les données risquent d'être perdues !",
	"Caractères nuls à la ligne %d",
	".ebrc : pas de nom de fonction à la ligne %d",
	".ebrc : le nom de fonction à la ligne %d commence par un chiffre",
	".ebrc : nom de fonction à la ligne %d trop long : la limite est de dix caractères",
	".ebrc : erreur de syntaxe dans la définition de fonction à la ligne %d",
	".ebrc : ligne %d,  \"condition > fichier\" attendu",
	".ebrc : ligne %d, la règle de filtrage ne correspond à aucune chaîne",
	".ebrc : ligne %d, la correspondance sur %s n'est pas définie",
	".ebrc : ligne %d, trop de filtres de courrier",
	".ebrc : mot clé %s inconnu à la ligne %d",
	".ebrc : ligne %d, l'attribut %s ne peut être défini hors d'un descripteur de courrier",
	".ebrc : ligne %d, l'attribut %s ne peut être défini hors d'un descripteur mime",
	".ebrc : ligne %d, l'attribut %s ne peut être défini hors d'un descripteur de table",
	".ebrc : ligne %d, l'attribut %s ne peut être défini dans un descripteur de courrier ou un bloc de filtrage",
	".ebrc : ligne %d, l'attribut %s ne peut être défini dans un descripteur mime",
	".ebrc : ligne %d, l'attribut %s ne peut être défini dans un descripteur de table",
	".ebrc : ligne %d, l'attribut %s n'est pas défini",
	".ebrc : ligne %d,trop de connes, la limite est de %d",
	".ebrc : ligne %d, la colonne index ne peut être que numérique",
	".ebrc : colonne index hors limites; seules %d colonnes ont été spécifiées",
	".ebrc : le carnet d'adresses %s n'est pas un fichier régulier",
	0,
	".ebrc : %s n'est pas un répertoire",
	".ebrc : ligne %d, trop d'agents utilisateurs, la limite est de 9",
	".ebrc : le récipient de cookies n'est pas un fichier régulier",
	".ebrc : impossible de créer   le récipient de cookies",
	".ebrc : trop de directives no js, la limite est de %d",
	".ebrc : ligne %d, le domaine ne contient pas de point",
	".ebrc : la corbeille de courrier n'est pas un fichier régulier",
	".ebrc : le fichier de certificats SSL n'est pas un fichier régulier",
	".ebrc :  fichier de certificats SSL absent ou illisible",
	".ebrc : ligne %d, le mot-clé %s n'est pas encore implémenté",
	".ebrc : plus d'un compte mail est défini comme compte par défaut",
	".ebrc : serveur entrant manquant",
	".ebrc : serveur sortant manquant",
	".ebrc : nom d'utilisateur manquant",
	".ebrc : mot de passe manquant",
	".ebrc : ligne from manquante à la ligne %d",
	".ebrc : ligne reply manquante à la ligne %d",
	".ebrc : type manquant à la ligne %d",
	".ebrc : description manquante à la ligne %d",
	".ebrc : suffixe ou liste de protocoles manquants à la ligne %d",
	".ebrc : programme manquant à la ligne %d",
	".ebrc : nom de table manquant à la ligne %d",
	".ebrc : surnom manquant à la ligne %d",
	".ebrc : colonnes manquantes à la ligne %d",
	".ebrc : } inattendue à la ligne %d",
	".ebrc : else à la ligne %d ne fait pas partie d'une instruction",
	".ebrc : texte altéré à la ligne %d",
	".ebrc : la ligne %d ne peut lancer une fonction, un descripteur mime ou de type, ou un filtre dans %s",
	".ebrc : l'instruction à la ligne %d doit apparaître dans une fonction",
	"Trop de comptes de courrier dans votre fichier de configuration, la limite est de %d",
	"Trop de types mime dans votre fichier de configuration, la limite est de %d",
	"Trop de tables sql dans votre fichier de configuration, la limite est de %d",
	"Trop de fonctions dans votre fichier de configuration, la limite est de %d",
	".ebrc : ligne %d, trop de structures imbriquées",
	".ebrc : la fonction %s n'est pas fermée",
	".ebrc : le bloc mime ou courrier n'est pas fermé",
	"Votre répertoire personnel n'est pas défini par la variable $HOME",
	"%s n'est pas un répertoire",
	"Pas de comptes de courrier définis, vérifiez votre fichier .ebrc",
	"Numéro de compte de courrier invalide, utilisez svp de 1 à %d",
	"edbrowse  -v    (montre version)\nedbrowse -h (ce message)\nedbrowse -c (edit fichier config)\nedbrowse  [-e] [-d#] -[p]m#    (lecture courrier \nedbrowse  [-e] [-d#] -m# adresse1 adresse2 ... fichier [+pièces jointes]\nedbrowse  [-e] [-d#] fichier1 fichier2 ...",
	"Définissez s'il vous plaît au moins un destinataire et le fichier à envoyer",
	"Définissez s'il vous plaît au moins un destinataire et le fichier à envoyer, avant vos pièces jointes",
	"Trop de fichiers ouverts, la limite est de %d",
	"Session %d invalide dans la fonction fetchLineContext()",
	"Numéro %d de ligne invalide dans la fonction fetchLineContext()",
	"Trop de proxy dans votre fichier de configuration, la limite est de %d",
	"La session %d est hors limites dans cxActive",
	"Double init dans la session %d",
	"Quitte la session %d inactive",
	"Nouveau morceau vide dans la fonction addToMap()",
	"Pas de retour-chariot après la ligne du répertoire %s",
	"Pas de caractère  > dans la ligne %d",
	"FieldInBuffer ne peut trouver le tag %d nouveau texte %s",
	"Impossible de reconstruire votre récipient %s de cookies",
	0,
	"Le client de courrier est interactif, et ne peut être lancé en arrière-fond",
	"répertoire de courrier non défini dans votre fichier .ebrc",
	"Ne peut aller dans le répertoire %s",
	0,
	"nom utilisateur / mot de passe invalide",
	0,
	0,
	0,
	0,
	0,
	"Le tag %d est suivi d'un caractère %c erroné",
	0,
	"HtmlParse() n'est pas réentrant",
	"Type de données inattendu dans submitForm()",
	"List = 0 dans tagFromJavaVar()",
	0,
	"Impossible d'allouer de la mémoire pour les opérations javascript",
	"Impossible de créer un contexte javascript",
	"Impossible de créer un objet fenêtre pour javascript",
	"Impossible de créer les classe standards pour javascript",
	"Impossible de créer un document objet pour javascript",
	"Hostname:port trop long",
	"Protocol: trop long",
	"Erreur alloc de %zu octets",
	"Erreur calloc de %zu octets",
	"reallocMem(p,0)",
	"reallocMem(0,%zu)",
	"Erreur de ré-allocation de %zu octets",
	"StringInList(null,...)",
	"StringInListCI(null,...)",
	"charInList(null,...)",
	"Pointeur nul dans pstLength",
	"Impossible d'utiliser ioctl() pour gérer le terminal",
	"Impossible d'ouvrir %s",
	"Impossible de créer ou d'écrire %s",
	"Mode d'appel %s de fopen() invalide",
	"/ mal placé dans getDirUrl(%s)",
	"/ mal placé dans %s",
	"decodePostData(0,0)",
	"impossible de convertir le pdf en html : assurez-vous d'avoir pdftohtml installé, et essayez de le lancer sur %s",
	0,
	0,
	"impossible de répondre en mode répertoire",
	"impossible de répondre en mode base de données",
	"impossible de répondre à un fichier vide",
	"impossible de répondre à un fichier binaire",
	"lignes 'subject' et 'reply' obligatoires",
	"attention, pas d'identificateur ID de message pour le référencer",
	"Désolé, pas d'en-têtes de courrier.\nVous devez commencer avec un courrier non formaté, le consulter, puis répondre à tous.",
	"l affiche tous les caractères de contrôle en hexadécimal",
	"l affiche tous les caractères non-ascii et de contrôle en hexadécimal",
	"Attention : les fonctions de recherche/remplacement ne fonctionneront pas avec les caractères utf8,\nparce que cette fonctionnalité est absente de la librairie pcre.\nExportez PCREUT8=off pour désactiver cette fonctionnalité et supprimer ce message d'avertissement",
	"converti en utf8",
	"converti en iso8859",
	"pas de conversion entre iso8859 et utf8",
	"conversion automatique entre iso8859 et utf8",
	"impossible de copier un répertoire dans la corbeille sur un autre système de fichiers;n utilisez cpio -p ou cp -r à partir du shell",
	"impossible de supprimer un répertoire; utilisez rm -r à partir du shell",
	"Echec à l'initialisation de libcurl.",
	"Ce répertoire ftp est vide.",
	"recherche et remplacement en ascii",
	"recherche et remplacement en utf8",
	"Attention: vous devriez désactiver (temporairement) la recherche/remplacement en utf8\n avec la commande su8 pour que cela fonctionne correctement.",
	"la clé primaire comprend plus de 3 colonnes",
	"impossible de déterminer la prochaine valeur de la clé auto(0)",
	"les noms de table sont dans le tampon %d\n",
	"pas de source de données spécifiée",
	"connexion à la source de données %s\n",
	"ligne",
	"lignes",
	"sélectionné",
	"inséré",
	"mis à jour",
	"supprimé",
	"procédure exécutée",
	"table",
	"instruction sql non suivie d'un point-virgule ou d'un crochet fermant sur la ligne suivante",
	"instruction update ou delete sans clause where",
	"accès distant refusé",
	"autorisation nécessaire pour accéder à %s",
	"l'opération a échoué : impossibilité d'allouer de la mémoire",
	"votre version de la librairie libcurl est antérieure à %u.%u.%u.\nMettez à jour libcurl pour utiliser edbrowse.",
	"délai d'attente de l'opération dépassé",
	"impossible d'envoyer des données au serveur",
	"la librairie curl a renvoyé ce message d'erreur suite à l'opération demandée : %s",
	"clés extérieures pour %s\n",
	"ne pas extraire de colonnes blob",
	"extraction de colonnes blob",
	"Erreur de connexion SSL dans libcurl: %s",
	"entrées tty",
	"entrées readline()",
	0,
	"Erreur Javascript irrécupérable dans cette session, javascript est fermé.",
	"gestionnaire onclick inaccessible",
	"Impossible de parcourir les données URI contenant JavaScript",
};

/* Translation by Cleverson Casarin: clcaul@gmail.com */
static const char *brazilianPortugueseMessages[] = {
	"Fim do arquivo",
	"nenhum arquivo",
	"nenhum",
	"substituição é global",
	"substituição é local",
	"não diferencia maiúsculas",
	"diferencia maiúsculas",
	"diretório é somente leitura",
	"diretório pode ser escrito",
	"diretório pode ser escrito e seu conteúdo apagado",
	"sem redirecionamento http",
	"redirecionamento http",
	"não envia referência",
	"envia referência",
	"javascript desligado",
	"javascript ligado",
	"criando binário como texto",
	"cuidando arquivos binários",
	"modo passivo",
	"modo ativo",
	"O mecanismo de Javascript falhou; todas as sessões atuais de Javascript foram encerradas.",
	"não verifica conexões SSL (menos seguro)",
	"verifica conexões SSL",
	"não exibe arquivos ocultos no modo diretório",
	"exibe arquivos ocultos no modo diretório",
	"Impossível bifurcar processo filho para edbrowse-js, Javascript foi desabilitado.",
	"Impossível executar edbrowse-js, Javascript foi desabilitado.",
	"marcadores de fim desligados",
	"marcadores de fim em linhas listadas",
	"marcadores de fim ligados",
	"javascript desativado; nenhuma ação",
	"javascript está desativado;indo direto à URL",
	"redirecionamento interrompido pelo usuário",
	"vazio",
	"nova sessão",
	"nenhum espaço de linha nova",
	"modo diretório",
	"dados binários",
	"OK",
	" [binário]",
	"sem título",
	"sem descrição",
	"sem palavras chave",
	"sessção %d\n",
	"linque de correio.  Escreva a carta, digite sm para enviar e depois ^ para voltar.",
	"linha %d atualizada\n",
	"sem assunto",
	"sem arquivo de configuração",
	"arquivo de configuração .ebrc não contém blocos subjfilter{...}",
	"interrompendo; digite qt para sair completamente",
	"edbrowse ativado",
	"comando contém caracteres nulos; você pode usar \\0 numa cadeia de busca/substituição para indicar nulos",
	"autorização solicitada - digite x para cancelar.",
	"redirecionamentos demais",
	"sucesso",
	"diretório",
	"redireção para %s atrasada em %d segundos\n",
	"Nome de usuário: ",
	"nome de usuário longo demais; limite %d caracteres",
	"Senha: ",
	"senha longa demais; limite %d caracteres",
	"Impossível comunicar-se com edbrowse-js, Javascript foi desabilitado.",
	"aviso: diretório inacessível - listagem ficará vazia",
	"catástrofe; mensagem de erro %d é comprida demais\n",
	"linha %d: ",
	"erro de navegação: ",
	"exibidor %d foi atualizado\n",
	"sem opções",
	"formulário limpo",
	"submetendo formulário",
	"criada janela separada no buffer %d\n",
	" muitos",
	" recomendado",
	"]",
	"sem opções com a cadeia %s\n",
	"enviando carta para %s\n",
	"informação enviada; aguarde resposta por e-mail.",
	"lixo",
	"sair",
	"próximo",
	"apagar",
	"apagar IP",
	"a opção -p desativa este recurso",
	"Impossível configurar o ambiente de execução Javascript, Javascript foi desabilitado.",
	"fim da mensagem",
	"não implementado ainda",
	"nome do arquivo: ",
	"arquivo %s já existe.\n",
	"abreviado",
	"anexo vazio",
	"anexo ",
	"sem buffers; anexos descartados",
	"não foi possível copiar o anexo para o buffer %d",
	"impossível criar o arquivo %s; anexo descartado\n",
	"impossível escrever no arquivo %s; anexo descartado\n",
	"sem cartas",
	"%d mensagens\n",
	"Mensagens interprocessos de Javascript não estão em sincronia.",
	" de",
	"?\tmostra esta mensagem de ajuda.\nq\tsai do programa.\nespaço\tcontinua a ler esta carta.\nn\tvai para próxima carta.\nd\tapaga carta.\nw\tguarda carta em arquivo e apaga carta.\nu\tguarda carta em arquivo sem formatar e apaga carta",
	"impossível criar o arquivo %s\n",
	"impossível escrever no arquivo %s\n",
	"carta salva; %d bytes",
	" adicionado",
	"página terminou; por favor use a tecla de retorno ou saia",
	"atualização de texto interno não implementada ainda.",
	"sem erros",
	"autenticação proxy para URL não proxy",
	"sessão %d não ativa",
	"sessão 0 é inválida",
	"a sessão %d está fora do limite %d",
	"já está na sessão %d",
	"esperando `w'",
	"esperando `w' na sessão %d",
	"limite de 170 milhão de linhas alcansado.\nSalve os arquivos, saia e reinicie o programa.",
	"caminho absoluto comprido demais; o limite é de %d caracteres",
	"os diretórios são somente leitura; digite dw para ativar a escrita em diretórios",
	"não foi possível criar o .Trash no seu diretório home para armazenar arquivos apagados",
	"não foi possível remover o arquivo %s",
	"não foi possível mover %s para a lixeira; ative o modo dx para remover permanentemente o arquivo",
	"local de destino fica dentro do bloco a copiar ou mover",
	"sem mudança",
	"impossível juntar uma linha",
	"impossível ler do banco de dados para outro arquivo",
	"impossível ler tabelas diferentes dentro da mesma sessão",
	"nome do arquivo faltando",
	"domínio vazio na URL",
	"impossível escrever numa URL",
	"impossível escrever numa tabela do banco de dados",
	"impossível escrever um arquivo vazio",
	"impossível criar %s",
	"impossível escrever em %s",
	"sessão não interativa",
	"linha %c fora do intervalo",
	"impossível embutir caracteres nulos num comando de shell",
	"rótulo %c não definido",
	"delimitador inválido",
	"nenhuma cadeia de busca memorizada",
	"nenhuma cadeia de substituição memorizada",
	"expressão regular longa demais",
	"a linha termina em barra invertida",
	"fecho inesperado )",
	"cadeia de substituição pode usar apenas $1 até $9",
	"o modificador %s não possui caractere predecessor",
	"sem fecho ]",
	"sem fecho )",
	"buffer vazio",
	"erro na expressão regular; %s",
	"erro inesperado a avaliar a expressão regular na linha %d",
	"cadeia não achada",
	"número de linha grande demais",
	"número de linha negativo",
	"sem expressão regular após %c",
	"delimitador faltando",
	"nenhuma linha condiz com o padrão g",
	"todas as linhas condizem com o padrão v",
	"nenhuma linha marcada modificada com sucesso",
	"operação interrompida",
	"nada similar",
	"Objetos Javascript estão faltando ou desconfigurados.",
	"agente número %c não definido",
	"não foi possível mostrar diretório novo",
	"não foi possível estabelecer o diretório atual",
	"diretório inválido",
	"impossível reproduzir áudio a partir de um buffer vazio",
	"impossível reproduzir áudio em modo navegação",
	"impossível reproduzir áudio em modo de diretório",
	"impossível reproduzir áudio em modo banco de dados",
	"arquivo não tem sufixo; use mt.xxx para especificar um sufixo próprio",
	"sufixo pode ter no máximo 5 caracteres",
	"sufixo .%s não é um mime conhecido; consulte por favor o arquivo de configuração.",
	"sem arquivo ou URL para atualizar",
	"não está em modo banco de dados",
	"não está em modo navegação",
	"nome do arquivo não possui /",
	"nome do arquivo termina em /",
	"caracteres inválidos após o comando sm",
	"você deve especificar exatamente um dos %s após o comando B",
	"linha não possui um %c de abertura",
	"ambos %c e %c não estão completados nesta linha; experimente B%c ou B%c",
	"linha não possui uma chave, um parêntese ou um colchete não completado",
	"impossível achar a linha que completa o %c",
	"sessão %d está atualmente em modo navegação",
	"sessão %d está atualmente em modo diretório",
	"sem nome de arquivo",
	"fim do buffer",
	"sem mais linhas para juntar",
	"intervalo não recomendado",
	"impossível quebrar linhas em modo diretório",
	"impossível quebrar linhas em modo banco de dados",
	"impossível quebrar linhas em modo navegação",
	"comando %c desconhecido",
	"%c não disponível em modo diretório",
	"%c não disponível em modo banco de dados",
	"%c não disponível em modo navegação",
	"número de linha zero",
	"sem espaço após comando",
	"o comando %c não se aplica globalmente",
	"local de destino para cópia/moção inválido",
	"texto inesperado após o comando %c",
	"nada a desfazer",
	"por favor entre k[a-z]",
	"impossível rotular um intervalo inteiro",
	"copiar 0 é inválido",
	"aviso: nenhum buffer disponível para gerir a janela auxiliar",
	"texto inesperado após o comando q",
	"impossível trocar o nome de um diretório",
	"impossível trocar o nome de uma tabela",
	"impossível adicionar a outro buffer",
	"sem arquivo especificado",
	"impossível escrever no diretório; os arquivos são modificados conforme você tenta",
	"impossível escrever no banco de dados; as linhas são modificadas conforme você tenta",
	"texto inesperado após o comando ^",
	"sem texto anterior",
	"texto inesperado após o comando M",
	"sessão destino não especificada",
	"sem texto anterior; impossível copiar",
	"impossível aplicar comando g a um intervalo",
	"g não disponível em modo banco de dados",
	"impossível aplicar comando i%c a um intervalo",
	"impossível usar i< num comando global",
	"o buffer %d está vazio",
	"o buffer %d contém mais que uma linha",
	"impossível abrir %s",
	"impossível ler a partir de %s",
	"texto de entrada contém caracteres nulos",
	"a linha possui um retorno de carro embutido",
	"a primeira linha do %s é comprida demais",
	"arquivo atualmente no buffer - use por favor o comando rf para atualizar",
	"impossível navegar num arquivo binário",
	"impossível navegar num arquivo vazio",
	"isto não parece um texto navegável",
	"já está navegando",
	"rótulo %s não achado",
	"i não disponível em modo navegação",
	"impossível executar um comando insert a partir de uma função do edbrowse",
	"Impossível comunicar-se com edbrowse-js, Javascript está fechado.",
	"comando %c ainda não implementado",
	"%d está fora do intervalo",
	"não há opções com a cadeia %s",
	"várias opções contêm a cadeia %s",
	"botão; use i* para pressioná-lo",
	"botão de submeter; use i* para pressioná-lo",
	"botão de limpar; use i* para pressioná-lo",
	"área de edição; edite na sessão %d",
	"somente leitura",
	"campo de entrada não pode ter caracteres de nova linha",
	"entrada comprida demais; o limite é de %d caracteres",
	"campo deve ser preenchido com + ou -",
	"não pode desmarcar um botão de opção; tem que marcar outro",
	"%s não é um arquivo acessível",
	"espera-se um número",
	"a sessão %d contém caracteres nulos",
	"enviar um arquivo requer method=post e enctype=multipart/form-data",
	"isto é um campo de entrada e não um botão",
	"botão não faz parte de um formulário",
	"sem javascript associado a este botão",
	"formulário não inclui URL de destino",
	"ação do formulário não é uma URL",
	"javascript desligado; impossível ativar este formulário",
	"formulário mudou de https para http e agora não é seguro",
	"impossível submeter usando protocolo %s",
	"%d fora do intervalo; por favor use %c1 até %c%d",
	"%d fora do intervalo; por favor use %c1 ou simplesmente %c",
	"impossível substituir várias ocorrências de uma cadeia vazia",
	"transferência abortada.",
	"sem expressão regular após %c",
	"vários números após o terceiro delimitador",
	"sufixo de substituição inesperado após o terceiro delimitador",
	"impossível usar um sufixo numérico e o sufixo `g' simultaneamente",
	"impossível aplicar o comando bl a linhas maiores que %d bytes",
	"dados de substituição contêm linhas novas",
	"dados de substituição contêm caracteres nulos",
	"impossível embutir barra, nova linha ou caractere nulo num nome de diretório",
	"arquivo destino já existe",
	"impossível renomear o arquivo para %s",
	"impossível embutir caracteres nulos num campo de entrada",
	"impossível embutir novas linhas num campo de entrada",
	"sem campos de entrada presentes",
	"sem linques presentes",
	"sem botões presentes",
	"presentes vários campos de entrada; por favor use %c1 até %c%d",
	"presentes vários linques; por favor use %c1 até %c%d",
	"presentes; por favor use %c1 até %c%d",
	"não consegui ler os dados do servidor",
	"%s não é uma URL",
	"transferência completa",
	"impossível identificar %s na rede",
	"o protocolo %s não é suportado pelo edbrowse e não está incluído nos tipos mime do arquivo de configuração",
	"aviso: não foi possível precarregar o <buffer %d> com o texto inicial do mesmo\n",
	"transferência em progresso",
	"não é possível conectar a %s",
	"transferência: ",
	"o certificado do servidor %s não pôde ser verificado - conexão SSL abortada",
	"texto novo acrescentado na linha %d\n",
	"?\tescreve esta mensagem de ajuda.\nq\tsai deste programa.\nspace\tlê mais desta mensagem de e-mail.\nn\tvai para a próxima mensagem de e-mail.\nd\tapaga esta mensagem.\nw\tguarda esta mensagem em arquivo.\nW\tgrava esta mensagem em arquivo e a apaga.\nu\tgrava esta mensagem sem formatação em arquivo.\nU\tgrava esta mensagem sem formatação em arquivo e a apaga.\na\tprocura e salva anexos.\ns\tinterrompe a leitura de e-mails desta pasta.",
	"página da web requer autorização",
	"Login cancelado",
	"?: escreve esta mensagem de ajuda.\nq: sai deste programa.\ng nome|#: vai para a pasta.\nl: lista as pastas com e-mails não lidos.\na: lista todas as pastas.\nc nome: cria uma nova pasta.\nd nome|#: apaga pasta.",
	"não é possível escrever no arquivo temporário %s para descomprimir a página da web",
	"transferir em primeiro plano",
	"transferir em segundo plano",
	"terminou",
	"falhou",
	"o FTP não conseguiu conectar ao servidor remoto",
	"o FTP não conseguiu conectar ao servidor remoto (tempo esgotado)",
	"transferência FTP falhou",
	"transferência FTP falhou (tempo esgotado)",
	"ativa",
	"interromper",
	"URL FTP mal-formada",
	"sem anexos",
	0,
	0,
	"falha a iniciar sessão de FTP",
	0,
	"o edbrowse não foi compilado com acesso a bancos de dado",
	"faltando apelido na linha %d do catálogo de endereços",
	"faltando : na linha %d do catálogo de endereços",
	"o apelido na linha %d do catálogo de endereços é comprido demais; o limite é de 15 caracteres",
	"o e-mail na linha %d do catálogo de endereços é comprido demais; o limite é de 63 caracteres",
	" o e-mail na linha %d do catálogo de endereços não possui uma @",
	"impossível deixar espaços em branco em endereços de e-mail; linha %d do catálogo de endereços",
	"caracteres não imprimíveis no apelido ou no e-mail; linha %d do catálogo de endereços",
	"a última linha do catálogo de endereços não possui terminação",
	0,
	0,
	0,
	0,
	0,
	"aviso: a URL do formulário especifica uma sessão %s que será ignorada\n",
	"arquivo %s vazio",
	"carta deve começar pelo assunto:",
	0,
	"assunto comprido demais; o limite é de %d caracteres",
	0,
	".signature não é um arquivo regular",
	"impossível acessar o arquivo .signature",
	"não é possível enviar o arquivo binário %s; quem sabe ele devesse ser um anexo ?",
	"ou nenhum ou todos os anexos têm de ser declarados como \"alternative\"",
	"destinatários demais; limite é %d",
	"sem catálogo de endereço; confira por favor seu arquivo de configuração .ebrc",
	"apelido %s não achado no catálogo de endereços",
	"nenhum destinatário especificado",
	"sessão %d vazia; impossível anexar",
	"impossível acessar o anexo %s",
	"o arquivo %s não é regular; impossível anexar",
	" arquivo %s vazio; impossível anexar",
	0,
	0,
	"servidor recusou %s",
	0,
	0,
	"sem contas de correio; confira por favor o arquivo de configuração",
	"número de conta %d inválido; por favor use 1 até %d",
	"não posso enviar cartas em modo navegação",
	"não posso enviar cartas em modo banco de dados",
	"não posso enviar cartas em modo diretório",
	"não posso enviar dados binários; isto não tem que ser um anexo ?",
	"não posso enviar um arquivo vazio",
	"sem destinatário na linha %d",
	"não posso enviar CC ou CCO para o primeiro destinatário",
	"sem anexo na linha %d",
	"número de conta inválido na linha %d",
	0,
	"a linha %d deve começar com to: attach: alt: account: ou subject:",
	0,
	"sem destinatário; coloque to: endereco no topo do arquivo",
	"%s:// esperado",
	"protocolo desconhecido  %s",
	":porta inválida ao final do domínio",
	"nome de domínio longo demais",
	"nome de usuário longo demais",
	"senha longa demais",
	0,
	0,
	"sem função especificada",
	"o nome da função deve conter apenas letras e números",
	"função %s não existe",
	"argumentos demais",
	"~%d não possui argumento correspondente",
	"não consegui executar o subcomando %s; erro %d",
	"não consegui criar o arquivo temporário %s; erro %d",
	"tabelas SQL demais no cache; limite é %d",
	"%s não é um arquivo regular",
	0,
	"impossível ler o conteúdo do %s",
	"impossível acessar %s",
	"variável de ambiente não definida",
	"não é possível expandir * ? ou [] antes da última /",
	"%s não é um diretório acessível",
	"padrão shell comprido demais",
	"Desculpe, não sei como expandir nomes de arquivo que contenham \\",
	"padrão [] formado de maneira inadequada",
	"erro a compilar o padrão shell; %s",
	"erro inesperado a avaliar o padrão shell",
	"padrão shell não condiz com nenhum arquivo",
	"padrão shell condiz com mais que um arquivo",
	"as linhas ficam longas demais quando as variáveis do shell são expandidas",
	"o arquivo de configuração não especifica um banco de dados - impossível conectar",
	"não consigo conectar ao banco de dados - erro %d",
	"erro SQL inesperado; %d",
	"sem coluna chave especificada",
	"nome de coluna %s é longo demais; limite é %d caracteres",
	"erro de sintaxe na cláusula where",
	"coluna %d fora do intervalo",
	"várias colunas condizem com %s",
	"nenhuma coluna condiz com %s",
	"tabela %s não existe",
	"nome de coluna inválido",
	"não posso selecionar mais que uma coluna de bolha",
	"dados possuem pipas que são os meus delimitadores reservados",
	"dados contêm novas linhas",
	"a linha possui campos demais; por favor não insira pipas no texto",
	"a linha possui muito poucos campos; por favor não remova nenhuma pipa do texto",
	"coluna chave não especificada",
	"erro miscelâneo de SQL; %d",
	"não posso apagar mais que 100 linhas de uma vez",
	"não posso alterar uma coluna chave",
	"não posso alterar um campo de bolha",
	"não posso alterar um campo de texto",
	"ops !  Apaguei %d linha(s) e %d entrada(s) de banco de dados foram afetadas.",
	"ops !  Inseri %d linha(s) e %d entrada(s) de banco de dados foram afetadas.",
	"ops !  Atualizei %d linha(s) e %d entrada(s) de banco de dados foram afetadas.",
	"outra linha no banco de dados depende desta",
	"a linha ou a tabela está bloqueada",
	"Você não tem permissão para modificar o banco de dados desse jeito",
	"paralização detectada",
	"colocando nulo numa coluna não nula",
	"restrição de conferência violada",
	"tempo do banco de dados esgotado",
	"impossível modificar um panorama",
	"sem fecho %s",
	"aviso: o javascript não pode ser invocado por eventos de teclas de atalho",
	"o javascript não pode ser invocado por foco ou imagem obscura",
	"manipulador onchange não está acessível",
	"%s não é parte de um formulário a ser preenchido",
	"%s não tem nome",
	"método desconhecido; por favor use GET ou POST",
	"codificação desconhecida; por favor use multipart/form-data ou application/x-www-form-urlencoded",
	"o formulário não pode submeter usando protocolo %s",
	"tipo de entrada %s desconhecido",
	"selecionados vários botões de opção",
	"%s fechado em %s",
	"%s começa no meio de %s",
	"fecho inesperado de %s que não foi aberto",
	"uma área de edição começa no meio de uma área de edição",
	"%s aparece no meio de uma âncora",
	"%s possui etiquetas HTML",
	"a opção não pode conter vírgula quando for parte de seleção múltipla",
	"opção vazia",
	"vários títulos",
	"%s não está numa lista",
	"%s não está numa tabela",
	"%s não está numa linha de tabela",
	"a opção aparece fora de uma seleção",
	"selecionadas várias opções",
	"ação de tag %d não processada",
	"%s não é fechado no fim do arquivo",
	"o java está abrindo uma janela vazia",
	"caracteres inesperados após o anexo codificado",
	"caracteres inválidos no anexo codificado",
	"o manipulador onchange não funciona com áreas de edição",
	"aviso: o javascript não pode ser invocado por duplo clique",
	"erro a resolver a opção %s durante um sync ou submissão de formulário",
	"a etiqueta não pode ter manipuladores onunload and onclik simultaneamente",
	"script não é fechado ao fim do arquivo; suspendendo javascript",
	"não consegui trazer o javascript local; %s",
	"não consegui trazer o javascript de %s; código %ld",
	"não consegui trazer o javascript; %s",
	"javascript desligado; ignorando código onclick",
	"javascript desligado; ignorando onchange código",
	"javascript desligado; ignorando código onreset",
	"javascript desligado; ignorando código onsubmit",
	"não consegui achar a etiqueta HTML associada à variável javascript que está sendo modificada",
	"o javascript modificou uma área de edição e isso não foi implementado ainda",
	"aviso: diretiva de atualização adulterada; %s\n",
	0,
	"aviso: redirecionamento HTTP %ld mas não foi especificada uma URL nova\n",
	"aviso: erro de HTTP %ld, %s\n",
	0,
	"aviso: impossível atualizar arquivo de configuração",
	"mensagens de ajuda ligadas",
	"download via FTP: ",
	"nenhum arquivo de certificados SSL; conexões seguras não podem ser verificadas",
	"não foi possível reescrever o arquivo de configuração; dados de configuração podem ser perdidos !",
	".ebrc: caracteres nulos na linha %d",
	".ebrc: falta nome de função na linha %d",
	".ebrc: nome de função na linha %d começa com um algarismo",
	".ebrc: nome de função na linha %d é longo demais; o limite é dez caracteres",
	".ebrc: a sintaxe de definição de função na linha %d é imprópria",
	".ebrc: linha %d, esperado \"condição > arquivo\" ",
	".ebrc: linha %d, regras de filtragem não têm cadeias a coincidir",
	".ebrc: linha %d, critério em %s não está definido em lugar algum",
	".ebrc: linha %d, filtros de e-mail em ecesso",
	".ebrc: palavra-chave desconhecida %s na linha %d",
	".ebrc: linha %d, o atributo %s não pode ser definido fora de um descritor de mensagem",
	".ebrc: linha %d, o atributo %s não pode ser definido fora de um descritor mime",
	".ebrc: linha %d, o atributo %s não pode ser definido fora de um descritor de tabela",
	".ebrc: linha %d, o atributo %s não pode ser definido dentro de um descritor de mensagem ou bloco de filtro",
	".ebrc: linha %d, o atributo %s não pode ser definido dentro de um descritor de mime",
	".ebrc: linha %d, o atributo %s não pode ser definido dentro de um descritor de tabela",
	".ebrc: linha %d, o atributo %s está definido para nada",
	".ebrc: linha %d, colunas em excesso; o limite é %d",
	".ebrc: linha %d, keycol tem que ser número ou número,número",
	".ebrc: linha %d, keycol fora do intervalo; especificadas somente %d colunas",
	".ebrc: o catálogo de endereços %s não é um arquivo regular",
	0,
	".ebrc: %s não é um diretório",
	".ebrc: linha %d, agentes do usuário em excesso; o limite é 9",
	".ebrc: cookie jar %s não é um arquivo regular",
	".ebrc: não posso criar a cookie jar %s",
	".ebrc: diretivas no js em excesso; o limit é %d",
	".ebrc: linha %d, o domínio %s não possui ponto",
	".ebrc: lixeira de cartas %s não é um arquivo regular",
	".ebrc: arquivo de certificados SSL %s não é um arquivo regular",
	".ebrc: arquivo de certificados SSL %s não existe ou não é legível.",
	".ebrc: linha %d, palavra-chave %s não foi implementada ainda",
	".ebrc: definindo várias contas de e-mail como padrão",
	".ebrc: falta o servidor de entrada na linha %d",
	".ebrc: falta o servidor de saída na linha %d",
	".ebrc: falta o usuário na linha %d",
	".ebrc: falta a senha na linha %d",
	".ebrc: falta o remetente na linha %d",
	".ebrc: falta o endereço para resposta na linha %d",
	".ebrc: falta o tipo na linha %d",
	".ebrc: falta a descrição na linha %d",
	".ebrc: falta o sufixo ou a lista de protocolos na linha %d",
	".ebrc: falta o programa na linha %d",
	".ebrc: falta o nome da tabela na linha %d",
	".ebrc: falta o nome curto na linha %d",
	".ebrc: faltam colunas na linha %d",
	".ebrc: } inesperada na linha %d",
	".ebrc: else na linha %d não faz parte de um comando if",
	".ebrc: texto adulterado na linha %d",
	".ebrc: linha %d, impossível iniciar função, descritor de mail/mime ou bloco de filtro dentro de %s",
	".ebrc: comando na linha %d deve aparecer dentro de uma função",
	"contas de e-mail demais no arquivo de configuração .ebrc; o limite é %d",
	"tipos mime demais no arquivo de configuração .ebrc; o limite é %d",
	"tabelas SQL demais no arquivo de configuração .ebrc; o limite é %d",
	"funções demais no arquivo de configuração .ebrc; o limite é %d",
	".ebrc: linha %d, as estruturas de controle estão aninhadas até um nível alto demais",
	".ebrc: função %s não se fecha no fim do arquivo",
	".ebrc: mail ou bloco mime não se fecha no fim do arquivo",
	"diretório home não definido por $HOME.",
	"%s não é um diretório",
	"nenhuma conta de e-mail especificada; confira por favor o arquivo de configuração .ebrc",
	"número de conta inválido; por favor use 1 até %d",
	"edbrowse -v (mostra a versão)\nedbrowse -h (esta mensagem)\nedbrowse -c (edita arquivo de configuração)\nedbrowse [-e] [-d#] -f[#] (recebe cartas)\nedbrowse [-e] [-d#] -[p]m (lê cartas pendentes)\nedbrowse [-e] [-d#] -[p]fm[#] (recebe cartas e lê as cartas pendentes)\nedbrowse [-e] [-d#] -m[#] endereço1 endereço2 ... arquivo [+anexos]\nedbrowse [-e] [-d#] arquivo1 arquivo2 ...",
	"por favor especifique ao menos um destinatário e o arquivo a enviar",
	"por favor especifique ao menos um destinatário e o arquivo a enviar, antes dos anexos",
	"demais arquivos abertos ao mesmo tempo; o limite é %d",
	"sessão %d inválida na fetchLineContext()",
	"número de linha %d inválido na fetchLineContext()",
	"contas de proxy no arquivo de configuração .ebrc; o limite é %d",
	"sessão %d fora do intervalo na cxActive",
	"init duplo na sessão %d",
	"fechando sessão não ativa %d",
	"novo trecho vazio na addToMap()",
	"sem linha nova na entrada do diretório %s",
	"sem fecho > na linha %d",
	"fieldInBuffer não encontrou a etiqueta %d newtext %s",
	"impossível refazer a cookie jar %s",
	0,
	"o cliente de recepção de cartas é interativo e não pode rodar em segundo plano",
	"diretório para caixa de entrada não especificado no arquivo .ebrc",
	"não posso mudar para o diretório %s",
	0,
	"usuário ou senha inválido",
	0,
	0,
	0,
	0,
	0,
	"o código da etiqueta %d possui o caractere inválido %c a seguir",
	0,
	"htmlParse() não é reentrante.",
	"dipo de entrada inesperado na submitForm()",
	"lista = 0 in tagFromJavaVar()",
	0,
	"não consegui alocar memória para operação Javascript.",
	"impossível criar contexto Javascript ",
	"impossível criar objeto de janela para o Javascript",
	"impossível criar classes padrão para o Javascript",
	"impossível criar objeto de documento para o Javascript",
	"servidor:porta está comprido demais",
	"protocolo: está comprido demais",
	"erro a alocar %zu bytes",
	"erro a alocar %zu bytes",
	"reallocMem(p,0)",
	"reallocMem(0,%zu)",
	"erro a realocar %zu bytes",
	"stringInList(null,...)",
	"stringInListCI(null,...)",
	"charInList(null,...)",
	"ponteiro nulo na pstLength",
	"não posso usar ioctl() para controlar o TTY",
	"não é possível abrir %s",
	"não é possível criar ou escrever em %s",
	"chamando fopen() em modo inválido %s",
	"/ mal posicionada na getDirURL(%s)",
	"/ mal posicionada na %s",
	"decodePostData(0,0)",
	"Não foi possível converter o PDF para HTML; certifique-se que o PDFToHTML esteja instalado e tente usá-lo no %s",
	0,
	0,
	"não é possível replicar em modo diretório",
	"não é possível replicar em modo banco de dados",
	"não posso replicar para um arquivo vazio",
	"não posso replicar para um arquivo binário",
	"linhas subject e reply são obrigatórias",
	"aviso: não há ID da mensagem a referenciar",
	"Desculpe; o cabeçalho da carta não está disponível.\nComece com uma carta não formatada, escolha browse e depois reply all.",
	"l expande caracteres de controle para hexadecimais",
	"l expande caracteres de controle e não-ASCII para hexadecimais",
	"Atenção: as funções buscar e substituir não aceitarão caracteres UTF8\nporque a biblioteca PCRE que você tem instalada não suporta essa funcionalidade.\nExporte PCREUTF8=off para desabilitar esse recurso e suprimir este aviso.",
	"convertendo para iso8859",
	"convertendo para utf8",
	"não converta entre iso8859 e utf8",
	"converte automaticamente entre iso8859 e utf8",
	"Não posso copiar uma árvore de diretórios para uma lixeira em outro sistema de arquivos;\nUse cpio -p ou cp -r a partir do shell",
	"Não posso apagar uma árvore de diretórios; use rm -r a partir do shell",
	"Falha ao inicializar a biblioteca libcurl.",
	"Esta listagem do diretório FTP está vazia.",
	"procurar e substituir usando ASCII",
	"procurar e substituir usando UTF8",
	"Aviso: talvez você precise desabilitar temporariamente o UTF8 no procurar e substituir,\nusando o comando su8, para que isso funcione de modo adequado.",
	"chave primária ocupa mais de 3 colunas",
	"impossível determinar próxima coluna para a chave serial(0)",
	"Nomes das tabelas estão no búfer %d\n",
	"nenhuma fonte de dados especificada",
	"conectando à fonte de dados %s\n",
	"linha",
	"linhas",
	"selecionado",
	"inserido",
	"atualizado",
	"apagado",
	"procedimento executado",
	"tabela",
	"comando SQL não terminado por ponto e vírgula ou fecha colchetes na seguinte linha",
	"comando de atualizar ou apagar sem cláusula where",
	"acesso remoto negado",
	"Autorização necessária para acessar %s",
	"operação falhou porque a memória não pôde ser alocada",
	"A sua versão de libcurl é mais velha que a %u.%u.%u.\nVocê tem que atualizá-la para usar o Edbrowse.",
	"tempo limite da operação esgotado",
	"não é possível enviar dados ao servidor",
	"a biblioteca curl retornou o seguinte erro ao executar a operação solicitada: %s",
	"chaves estrangeiras para %s\n",
	"não pegar colunas de blob",
	"pegar colunas de blob",
	"Erro de conexão SSL na libcurl: %s",
	"TTY de entrada",
	"linha de entrada()",
	0,
	"Erro não-reparável de javascript nesta sessão, javascript está fechado.",
	"manipulador onclick não está acessível",
	"Impossível analizar URI com dados contendo JavaScript",
};

/* Translation by Wojciech Gac: wojciech.s.gac@gmail.com */
static const char *polishMessages[] = {
	"EOF - koniec pliku",
	"brak pliku",
	"brak",
	"globalne podstawienia",
	"lokalne podstawienia",
	"wielkość liter nieistotna",
	"wielkość liter istotna",
	"katalogi tylko do odczytu",
	"katalogi z prawem zapisu",
	"katalogi z prawem zapisu (wraz z usuwaniem)",
	"brak przekierowania HTTP",
	"przekierowanie HTTP",
	"nie wysyłaj adresu strony wywołującej (referrera)",
	"wysyłaj adres strony wywołującej (referrera)",
	"JavaScript włączony",
	"JavaScript wyłączony",
	"traktuj dane binarne jak tekst",
	"szukanie plików binarnych",
	"tryb pasywny",
	"tryb aktywny",
	"Silnik JavaScript zawiódł; wszystkie bieżące sesje JavaScript zostały zamknięte.",
	"nie weryfikuj połączeń SSL (mniej bezpieczne)",
	"weryfikuj połączenia SSL",
	"nie pokazuj ukrytych plików w trybie katalogu",
	"pokazuj ukryte pliki w trybie katalogu",
	"Nie można utworzyć procesu potomnego dla edbrowse-js, JavaScript został wyłączony.",
	"Nie można wykonać polecenia edbrowse-js, JavaScript został wyłączony.",
	"znaczniki końca linii wyłączone",
	"znaczniki końca linii włączone dla wyświetlonych linii",
	"znaczniki końca linii włączone",
	"JavaScript wyłączony, brak akcji",
	"JavaScript wyłączony, idziemy wprost pod URL",
	"przekierowanie przerwane przez użytkownika",
	"pusty",
	"nowa sesja",
	"brak znaku końca linii",
	"tryb katalogu",
	"dane binarne",
	"ok",
	" [binarny]",
	"brak tytułu",
	"brak opisu",
	"brak słów kluczowych",
	"sesja %d\n",
	"Odnośnik SendMail. Stwórz wiadomość, wpisz 'sm' by wysłać, potem '^' by wrócić",
	"wiersz %d został zaktualizowany\n",
	"brak tematu",
	"brak pliku konfiguracyjnego",
	"plik konfiguracyjny .ebrc nie zawiera bloku subjfilter{...}",
	"przerwanie, wpisz 'qt' by zakończyć",
	"edbrowse gotów",
	"wprowadzone polecenie zawiera puste znaki (NULL); możesz użyć '\\0' w poleceniu szukaj/zamień by je wskazać",
	"żądanie autoryzacji - wpisz 'x' by anulować",
	"zbyt wiele przekierowań",
	"sukces",
	"katalog",
	"przekierowanie do %s opóźnione o %d sekund\n",
	"Nazwa użytkownika: ",
	"nazwa użytkownika zbyt długa, ograniczenie do %d znaków",
	"Hasło: ",
	"hasło zbyt długie, ograniczenie do %d znaków",
	"Nie można skomunikować się z edbrowse-js, JavaScript został wyłączony.",
	"uwaga, katalog jest niedostępny - lista zawartości będzie pusta",
	"katastrofa, długość wiadomości o błędzie %d - zbyt duża",
	"wiersz %d: ",
	"błąd przeglądania: ",
	"bufor %d został zaktualizowany\n",
	"brak opcji",
	"formularz został zresetowany",
	"wysyłanie formularza",
	"Osobne okno zostało utworzone w buforze %d\n",
	" wiele",
	" zalecane",
	"]",
	"żadna opcja nie zawiera ciągu znaków %s\n",
	"wysyłanie wiadomości do %s\n",
	"Twoje informacje zostały wysłane; oczekuj odpowiedzi emailem zwrotnym.",
	"śmieci",
	"wyjdź",
	"następny",
	"usuń",
	"usuń IP",
	"opcja '-p' wyłącza tę funkcję",
	"Nie można skonfigurować środowiska uruchomieniowego JavaScript, JavaScript został wyłączony.",
	"koniec wiadomości",
	"nie zaimplementowano",
	"nazwa pliku: ",
	"Przykro mi, plik %s już istnieje\n",
	"skrócone",
	"pusty załącznik",
	"załącznik ",
	"brak wolnych buforów, załącznik odrzucony",
	"nie można skopiować załącznika do bufora %d",
	"nie można utworzyć pliku %s, załącznik odrzucony\n",
	"nie można zapisać pliku %s, załącznik odrzucony\n",
	"brak poczty",
	"%d wiadomości\n",
	"Komunikacja między procesami JavaScript jest rozsynchronizowana.",
	" od ",
	"?\twydrukuj ten wątek pomocy.\nq\tzakończ ten program.\nspacja\tczytaj więcej z tej wiadomości.\nn\tprzejdź do następnej wiadomości pocztowej.\nd\tusuń tę wiadomość.\nw\tzapisz tę wiadomość do pliku i usuń ją.\nu\tzapisz tę wiadomość do pliku w postaci niesformatowanej i usuń ją.",
	"nie można utworzyć pliku %s\n",
	"nie można zapisać pliku %s\n",
	"poczta zapisana, %d bajtów",
	" dopisano",
	"to koniec tej strony, użyj klawisza 'wstecz' lub wyjdź",
	"Przykro mi, aktualizacja 'innerText' nie została zaimplementowana",
	"brak błędów",
	"autoryzacja proxy dla URLa nie będącego proxy",
	"sesja %d jest nieaktywna",
	"sesja 0 nie jest dozwolona",
	"sesja %d jest poza dozwoloną granicą: %d",
	"jesteś już w sesji %d",
	"oczekiwano `w'",
	"oczekiwano `w' w sesji %d",
	"Twój limit 170 milionów wierszy został osiągnięty.\nZapisz swoje pliki, po czym wyjdź z programu i uruchom go ponownie.",
	"długość ścieżki bezwzględnej zbyt duża, limit: %d znaków",
	"katalogi są tylko do odczytu, wpisz 'dw' by uaktywnić zapis",
	"nie można utworzyć katalogu '.Trash' w Twoim katalogu domowym",
	"nie można usunąć pliku %s",
	"Nie można przenieść %s do śmieci, ustaw tryb 'dx' aby rzeczywiście usunąć plik",
	"lokalizacja docelowa znajduje się w kopiowanym/przenoszonym obszarze",
	"brak zmian",
	"nie można dołączyć wiersza",
	"nie można wczytać z bazy danych do innego pliku",
	"nie można wczytać innych tabel do tej samej sesji",
	"brak nazwy pliku",
	"pusta domena w adresie URL",
	"nie można zapisać pod adresem URL",
	"nie można zapisać do tabeli w bazie danych",
	"nie można zapisać pustego pliku",
	"nie można utworzyć %s",
	"nie można zapisać %s",
	"sesja nie jest interaktywna",
	"wiersz %c jest poza zakresem",
	"nie można włączać pustych znaków do poleceń",
	"etykieta %c nie jest ustawiona",
	"niedozwolony ogranicznik",
	"brak zapamiętanych fraz wyszukiwania",
	"brak zapamiętanych fraz podstawienia",
	"wyrażenie regularne zbyt długie",
	"wiersz kończy się ukośnikiem wstecznym (backslash)",
	"nieoczekiwany nawias zamykający ')'",
	"fraza podstawienia może wykorzystywać jedynie '$1' do '$9'",
	"modyfikator %s nie posiada znaku poprzedzającego",
	"brak zamykającego ']'",
	"brak zamykającego ')'",
	"pusty bufor",
	"błąd w wyrażeniu regularnym, %s",
	"nieoczekiwany błąd przy wykonywaniu wyrażenia regularnego w wierszu %d",
	"nie znaleziono frazy wyszukiwania",
	"numer wiersza zbyt duży",
	"ujemny numer wiersza",
	"brak wyrażenia regularnego po %c",
	"brak ogranicznika",
	"żaden wiersz nie pasuje do wzorca 'g'",
	"wszystkie wiersze pasują do wzorca 'v'",
	"żaden z zaznaczonych wierszy nie został poprawnie zmodyfikowany",
	"operacja przerwana",
	"brak pasujących wyników",
	"Brak obiektów JavaScript, lub zostały one błędnie skonfigurowane.",
	"agent numer %c nie został zdefiniowany",
	"nie można wyświetlić nowego katalogu",
	"nie można wykryć bieżącego katalogu",
	"niewłaściwy katalog",
	"nie można odtworzyć dźwięku z pustego bufora",
	"nie można odtworzyć dźwięku w trybie przeglądania",
	"nie można odtworzyć dźwięku w trybie katalogu",
	"nie można odtworzyć dźwięku w trybie bazy danych",
	"plik nie ma rozszerzenia, użyj 'mt.xxx' aby określić własne rozszerzenie",
	"rozszerzenie jest ogranicznone do 5 znaków",
	"rozszerzenie .%s nie jest rozpoznawanym typem MIME, sprawdź swój plik konfiguracyjny",
	"brak nazwy pliku lub URLa do odświeżenia",
	"nie jesteś w trybie bazy danych",
	"nie jesteś w trybie przeglądania",
	"nazwa pliku nie zawiera '/'",
	"nazwa pliku kończy się znakiem '/'",
	"niedozwolone znaki po poleceniu 'sm'",
	"musisz podać dokładnie jedno z '%s' po poleceniu 'B'",
	"wiersz nie zawiera otwartego %c",
	"zarówno %c jak i %c nie są domknięte w tym wierszu, spróbuj B%c lub B%c",
	"wiersz nie zawiera niedomkniętych nawiasów zwykłych, klamrowych ani kwadratowych",
	"nie można znaleźć wiersza z domknięciem %c",
	"sesja %d jest obecnie w trybie przeglądania",
	"sesja %d jest obecnie w trybie katalogu",
	"brak nazwy pliku",
	"koniec bufora",
	"nie ma dalszych wierszy do dołączenia",
	"nieprawidłowy zakres",
	"nie można łamać linii w trybie katalogu",
	"nie można łamać linii w trybie bazy danych",
	"nie można łamać linii w trybie przeglądania",
	"nieznane polecenie %c",
	"%c niedostępne w trybie katalogu",
	"%c niedostępne w trybie bazy danych",
	"%c niedostępne w trybie przeglądania",
	"zerowy numer wiersza",
	"brak spacji po poleceniu",
	"polecenie %c nie może być wykonane globalnie",
	"niewłaściwa lokalizacja docelowa dla przenoszenia/kopiowania",
	"nieoczekiwany tekst po poleceniu %c",
	"nie ma czego cofnąć",
	"proszę, wprowadź 'k[a-z]'",
	"nie można zaetykietować całego zakresu",
	"nie można wykonać kopii zapasowej 0",
	"uwaga: brak dostępnych buforów dla obsługi okna pomocniczego",
	"nieoczekiwany tekst po poleceniu 'q'",
	"nie można zmienić nazwy katalogu",
	"nie można zmienić nazwy tabeli",
	"nie można dołączyć do następnego bufora",
	"nie podano pliku",
	"nie można zapisać w katalogu; pliki będą modyfikowane na bieżąco",
	"nie można zapisać w bazie danych; rekordy będą modyfikowane na bieżąco",
	"nieoczekiwany tekst po poleceniu '^'",
	"brak poprzedniego tekstu",
	"nieoczekiwany tekst po poleceniu 'M'",
	"nie podano sesji docelowej",
	"brak poprzedniego tekstu, nie można zapisać",
	"nie można zastosować polecenia 'g' do zakresu",
	"polecenie 'g' niedostępne w trybie bazy danych",
	"nie można zastosować polecenia 'i%c' do zakresu",
	"nie można użyć 'i<' w poleceniu globalnym",
	"bufor %d jest pusty",
	"bufor %d zawiera więcej niż jeden wiersz",
	"nie można otworzyć %s",
	"nie można wczytać %s",
	"wprowadzony tekst zawiera puste znaki",
	"wiersz zawiera znak powrotu karetki",
	"pierwszy wiersz %s jest zbyt długi",
	"plik jest obecnie w buforze - użyj polecenia 'rf' by odświeżyć",
	"nie można przeglądać pliku binarnego",
	"nie można przeglądać pustego pliku",
	"to nie wygląda jak przeglądalny tekst",
	"już przeglądasz",
	"etykieta %s nie znaleziona",
	"'i' nie znalezione w trybie przeglądania",
	"nie można wywołać polecenia wstawienia z funkcji edbrowse",
	"Nie można skomunikować się z edbrowse-js, JavaScript został zamknięty.",
	"polecenie %c nie zaimplementowane",
	"%d jest poza zakresem",
	"żadna opcja nie zawiera ciągu %s",
	"wiele opcji zawiera ciąg %s",
	"to jest przycisk; użyj 'i*' aby go przycisnąć",
	"to jest przycisk wysyłania formularza; użyj 'i*' aby go przycisnąć",
	"to jest przycisk resetowania; użyj 'i*' aby go przycisnąć",
	"to jest pole tekstowe, musisz je edytować z poziomu sesji %d",
	"pole tylko do odczytu",
	"pole wprowadzania nie może zawierać znaku końca linii",
	"tekst zbyt długi, limit %d znaków",
	"pole musi zawierać + lub -",
	"nie możesz wyczyścić pola radio; musisz wybrać inne pole",
	"%s nie jest dostępnym plikiem",
	"oczekiwano liczby",
	"sesja %d zawiera znaki zerowe",
	"wysyłanie pliku wymaga parametrów method=post i enctype=multipart/form-data",
	"to jest pole wprowadzania, nie przycisk",
	"ten przycisk nie jest częścią formularza",
	"brak JavaScriptu powiązanego z tym przyciskiem",
	"formularz nie zawiera docelowego URLa",
	"akcja tego formularza nie jest URLem",
	"JavaScript jest wyłączony, nie można aktywować formularza",
	"Ten formularz zmienił się z http na https i nie jest teraz bezpieczny",
	"nie można wysłać używając protokołu %s",
	"%d jest poza zakresem, używaj %c1 do %c%d",
	"%d jest poza zakresem, użyj %c1 lub po prostu %c",
	"nie można zamienić wielu instancji pustego ciągu znaków",
	"anulowano pobieranie.",
	"brak wyrażenia regularnego po %c",
	"wiele liczb po trzecim ograniczniku",
	"nieoczekiwany tekst podstawienia po trzecim ograniczniku",
	"nie można użyć liczby i 'g' jednocześnie jako przyrostka",
	"przykro mi, nie można zastosować polecenia 'bl' do wierszy dłuższych niż %d bajtów",
	"dane podstawiane zawierają znaki końca linii",
	"dane podstawiane zawierają puste znaki",
	"nazwa katalogu nie może zawierać ukośnika, znaku końca linii ani znaku zerowego",
	"plik docelowy już istnieje",
	"nie można zmienić nazwy pliku na %s",
	"pole wprowadzania nie może zawierać znaków zerowych",
	"pole wprowadzania nie może zawierać znaków końca linii",
	"brak pól wprowadzania",
	"brak odnośników",
	"brak przycisków",
	"wiele pól wprowadzania obecnych, użyj %c1 do %c%d",
	"wiele odnośników obecnych, użyj %c1 do %c%d",
	"wiele przycisków obecnych, użyj %c1 do %c%d",
	"nie dało się wczytać danych z serwera",
	"%s nie jest URLem",
	"pobieranie zakończone.",
	"nie można zidentyfikować %s w sieci",
	"protokół %s nie jest wspierany przez edbrowse i nie jest zawarty w typach MIME w pliku konfiguracyjnym",
	"uwaga: nie można załadować <bufora %d> z tekstem początkowym\n",
	"pobieranie w toku",
	"nie można się połączyć z %s",
	"pobieranie: ",
	"Ceryfikat hosta %s nie mógł być zweryfikowany - połączenie SSL anulowane",
	"nowy tekst dodany w wierszu %d\n",
	"?\tpokaż treść tej pomocy.\nq\tzakończ ten program.\nspace\tprzeczytaj dalszą część tej wiadomości.\nn\tprzejdź do następnej wiadomości.\nd\tusuń tę wiadomość.\nw\tzapisz tę wiadomość do pliku.\nW\tzapisz tę wiadomość do pliku i usuń ją.\nu\tzapisz tę wiadomość do pliku w postaci niesformatowanej.\nU\tzapisz tę wiadomość do pliku w postaci niesformatowanej i usuń ją.\na\tprzeskanuj i zapisz załączniki.\ns\tzakończ czytanie poczty z tego katalogu.",
	"strona wymaga autoryzacji",
	"logowanie anulowane",
	"?\tpokaż treść tej pomocy.\nq\tzakończ ten program.\ng nazwa|#: idź do katalogu.\nl: lista katalogów z nieprzeczytanymi wiadomościami.\na: lista wszystkich katalogów.\nc nazwa: stwórz nowy katalog.\nd nazwa|#: usuń katalog.",
	"nie można zapisać pliku tymczasowego %s aby zdekompresować stronę",
	"pobieranie w głównym procesie",
	"pobieranie w tle",
	"ukończono",
	"niepowodzenie",
	"ftp: nie można połączyć się ze zdalnym hostem",
	"ftp: nie można połączyć się ze zdalnym hostem (przekroczono limit czasu)",
	"ftp: transfer zakończony niepowodzeniem",
	"ftp: transfer zakończony niepowodzeniem (przekroczono limit czasu)",
	"w toku",
	"stop",
	"ftp: błędny URL",
	"brak załączników",
	0,
	0,
	"ftp: inicjalizacja sesji zakończona niepowodzeniem",
	0,
	"edbrowse nie został skompilowany z dostępem do bazy danych",
	"brakujący alias w wierszu książki adresowej %d",
	"brakujący ':' w wierszu książki adresowej %d",
	"alias w wierszu książki adresowej %d jest zbyt długi, limit 15 znaków",
	"email w wierszu książki adresowej %d jest zbyt długi, limit 63 znaków",
	"email w wierszu książki adresowej %d nie zawiera '@'",
	"w emailu nie może być spacji, wiersz %d książki adresowej",
	"niedrukowalny znak w Twoim aliasie lub emailu, wiersz %d książki adresowej",
	"ostatni wiersz Twojej książki adresowej nie jest zakończony",
	0,
	0,
	0,
	0,
	0,
	"uwaga: URL formularza podaje sekcję %s, która zostanie zignorowana\n",
	"plik %s jest pusty",
	"Twoja wiadomość powinna zaczynać się od 'subject:'",
	0,
	"wiersz tematu zbyt długi, limit %d znaków",
	0,
	"'.signature' nie jest regularnym plikiem",
	"nie można odczytać pliku '.signature'",
	"nie można wysłać pliku binarnego %s, być może powinien być załącznikiem",
	"albo żaden albo wszystkie załączniki powinny być zadeklarowane jako 'alternative'",
	"zbyt wielu odbiorców, limit %d",
	"Nie podano książki adresowej, sprawdź swój plik konfiguracyjny '.ebrc'",
	"alias %s nie znaleziony w Twojej książce adresowej",
	"nie podano odbiorców",
	"sesja %d jest pusta, nie można załączyć",
	"nie można otworzyć załącznika %s",
	"plik %s nie jest regularnym plikiem, nie można załączyć",
	"plik %s jest pusty, nie można załączyć",
	0,
	0,
	"serwer pocztowy odrzucił %s",
	0,
	0,
	"nie podano żadnych kont pocztowych, sprawdź swój plik konfiguracyjny",
	"niewłaściwy numer konta %d, użyj liczby od 1 do %d",
	"nie można wysyłać wiadomości w trybie przeglądarki",
	"nie można wysyłać wiadomości w trybie bazy danych",
	"nie można wysyłać wiadomości w trybie katalogu",
	"nie można wysyłać danych binarnych, czy powinny być załącznikiem?",
	"nie można wysyłać pustych plików",
	"brak odbiorcy w wierszu %d",
	"nie można dodać pierwszego odbiorcy do 'cc' lub 'bcc'",
	"brak załącznika w wierszu %d",
	"błędny numer konta w wierszu %d",
	0,
	"wiersz %d powinien zaczynać się od 'attach:', 'alt:', 'account:' lub 'subject:'",
	0,
	"nie podano odbiorców, umieść 'to: <email>' na początku swojego pliku",
	"oczekiwano %s://",
	"nierozpoznany protokół %s",
	"nieprawidłowy specyfikator ':port' na końcu domeny",
	"nazwa domeny zbyt długa",
	"nazwa użytkownika zbyt długa",
	"hasło zbyt długie",
	0,
	0,
	"nie podano funkcji",
	"nazwa funkcji powinna zawierać jedynie litery i cyfry",
	"funkcja %s nie istnieje",
	"zbyt wiele argumentów",
	"~%d nie posiada odpowiadającego argumentu",
	"nie można wywołać subpolecenia %s, błąd %d",
	"nie można utworzyć tymczasowego pliku %s, błąd %d",
	"zbyt wiele tabel SQL w pamięci podręcznej, limit %d",
	"%s nie jest regularnym plikiem",
	0,
	"nie można wczytać zawartości %s",
	"nie można odczytać %s",
	"zmienna środowiskowa nie jest ustawiona",
	"nie można rozwinąć '*', '?' lub '[]' przed ostatnim znakiem '/'",
	"%s nie jest dostępnym katalogiem",
	"wzorzec powłoki jest zbyt długi",
	"przykro mi, nie wiem jak rozwinąć nazwy plików zawierające '\\'",
	"nieprawidłowo sformowany wzorzec '[]'",
	"błąd podczas kompilacji wzorca powłoki, %s",
	"nieoczekiwany błąd podczas wykonywania wzorca powłoki",
	"wzorzec powłoki nie pasuje do żadnego pliku",
	"wzorzec powłoki pasuje do więcej niż jednego pliku",
	"wiersz zbyt długi po rozwinięciu zmiennych powłoki",
	"plik konfiguracyjny nie podaje bazy danych - nie można połączyć",
	"nie można połączyć się z bazą danych - błąd %d",
	"błąd bazy danych %d",
	"brak klucza głównego dla tej tabeli",
	"nazwa kolumny %s jest zbyt długa, limit %d znaków",
	"błąd składniowy w wyrażeniu 'where'",
	"kolumna %d poza zakresem",
	"wiele kolumn pasuje do %s",
	"żadna kolumna nie pasuje do %s",
	"brak tabeli %s",
	"nieprawidłowa nazwa kolumny",
	"nie można wybrać więcej niż jednej kolumny BLOB",
	"dane zawierają pionowe kreski - zarezerwowany ogranicznik",
	"dane zawierają znaki końca linii",
	"wiersz zawiera zbyt wiele pól, nie wprowadzaj pionowych kresek do tekstu",
	"wiersz zawiera zbyt mało pól, nie usuwaj pionowych kresek z tekstu",
	"brak kolumny z kluczem głównym dla tej tabeli",
	"inny błąd SQL: %d",
	"nie można usunąć więcej niż 100 rekordów na raz",
	"nie można zmienić kolumny klucza",
	"nie można zmienić pola BLOB",
	"nie można zmienić pola tekstowego",
	"Ups! Usunąłem %d rząd(rzędów) i %d rekord(rekordów) zostało zmodyfikowanych",
	"Ups! Wstawiłem %d rząd(rzędów) i %d rekord(rekordów) zostało zmodyfikowanych",
	"Ups! Zaktualizowałem %d rząd(rzędów) i %d rekord(rekordów) zostało zmodyfikowanych",
	"inny rekord w bazie danych zależy od tego rekordu",
	"rekord lub tabela są zablokowane",
	"nie masz uprawnień by zmodyfikować bazę danych w ten sposób",
	"wykryto blokadę wzajemną (deadlock)",
	"umieszczono znak zerowy w kolumnie, w której jest to niedozwolone",
	"sprawdzić naruszenie więzów",
	"przekroczenie czasu dostępu do bazy danych",
	"nie można zmodyfikować widoku",
	"brak zamykającego %s",
	"uwaga, JavaScript nie może zostać wywołany przez zdarzenia z klawiatury",
	"JavaScript nie może zostać wywołany przez skupienie (focus) lub rozmycie (blur)",
	"obsługa zdarzenia 'onchange' nie jest dostępna",
	"%s nie jest częścią wypełnianego formularza",
	"%s nie posiada nazwy",
	"nierozpoznana metoda, użyj GET lub POST",
	"nierozpoznany 'enctype', użyj 'mulitpart/form-data' lub 'application/x-www-form-urlencoded'",
	"formularz nie może być wysłany protokołem %s",
	"nierozpoznany typ wejściowy %s",
	"wybrano wiele pól typu 'radio'",
	"%s jest domknięty wewnątrz %s",
	"%s zaczyna się w środku %s",
	"nieoczekiwane domknięcie %s, które nie zostało otwarte",
	"pole tekstowe rozpoczyna się wewnątrz innego pola tekstowego",
	"%s pojawia się wewnątrz kotwicy",
	"%s zawiera tagi HTML",
	"opcja nie może zawierać przecinka gdy jest częścią pola wielokrotnego wyboru",
	"pusta opcja",
	"wiele tytułów",
	"%s nie znajduje się wewnątrz listy",
	"%s nie znajduje się wewnątrz tabeli",
	"%s nie znajduje się wewnątrz wiersza tabeli",
	"opcja znajduje się poza wyrażeniem 'select'",
	"wybrano wiele opcji",
	"nieprzetworzona akcja tagu %d",
	"%s nie zostało zamknięte przed końcem pliku (EOF)",
	"Java otwiera puste okno",
	"nieoczekiwane znaki po zakodowanym załączniku",
	"nieprawidłowe znaki w zakodowanym ząłączniku",
	"obsługa 'onchange' nie działa z polem tekstowym",
	"uwaga, JavaScript nie może być wywołany podwójnym kliknięciem",
	"błąd użycia opcji %s podczas synchronizacji lub wysyłania formularza",
	"tag nie może posiadać opcji 'onunload' i 'onclick' jednocześnie",
	"skrypt nie kończy się na końcu pliku, zawieszenia JavaScript",
	"nie można pobrać lokalnego JavaScriptu, %s",
	"nie można pobrać JavaScriptu z %s, kod %ld",
	"nie można pobrać JavaScriptu, %s",
	"JavaScript wyłączony, pomijanie kodu 'onclick'",
	"JavaScript wyłączony, pomijanie kodu 'onchange'",
	"JavaScript wyłączony, pomijanie kodu 'onreset'",
	"JavaScript wyłączony, pomijanie kodu 'onsubmit'",
	"nie można znaleźć tagu HTML skojarzonego ze zmienną modyfikowaną w kodzie JavaScript",
	"JavaScript zmodyfikował pole tekstowe, nie jest to jeszcze zaimplementowane",
	"uwaga: zniekształcona dyrektywa odświeżania, %s\n",
	0,
	"uwaga: przekierowanie HTTP %ld, ale brak nowego adresu URL\n",
	"uwaga: błąd HTTP %ld, %s\n",
	0,
	"uwaga: nie można zaktualizować pliku konfiguracyjnego",
	"wiadomości pomocnicze włączone",
	"ściąganie ftp: ",
	"nie podano pliku z certyfikatem SSL; bezpieczne połączenie nie może zostać zweryfikowane",
	"nie można przepisać Twojego pliku konfiguracyjnego; Twoje dane konfiguracyjne mogły zostać utracone",
	".ebrc: znaki zerowe w wierszu %d",
	".ebrc: brak nazwy funkcji w wierszu %d",
	".ebrc: nazwa funkcji w wierszu %d zaczyna się od cyfry",
	".ebrc: nazwa funkcji w wierszu %d jest zbyt długa, limit 10 znaków",
	".ebrc: nieprawidłowa składnia definicji funkcji w wierszu %d",
	".ebrc: wiersz %d, oczekiwano 'warunek > plik'",
	".ebrc: wiersz %d, reguła filtracji nie posiada wzorca wyszukiwania",
	".ebrc: wiersz %d, dopasowanie %s nie jest nigdzie ustawione",
	".ebrc: wiersz %d, zbyt wiele filtrów poczty",
	".ebrc: nierozpoznane słowo kluczowe %s w wierszu %d",
	".ebrc: wiersz %d, atrybut %s nie może być ustawiony poza deskryptorem poczty",
	".ebrc: wiersz %d, atrybut %s nie może być ustawiony poza deskryptorem MIME",
	".ebrc: wiersz %d, atrybut %s nie może być ustawiony poza deskryptorem tabeli",
	".ebrc: wiersz %d, atrybut %s nie może być ustawiony poza deskryptorem poczty lub blokiem filtra",
	".ebrc: wiersz %d, atrybut %s nie może być ustawiony wewnątrz deskryptora MIME",
	".ebrc: wiersz %d, atrybut %s nie może być ustawiony wewnątrz deskryptora tabeli",
	".ebrc: wiersz %d, atrybut %s nie jest ustawiony",
	".ebrc: wiersz %d, zbyt wiele kolumn, limit %d",
	".ebrc: wiersz %d, klucz powinien być postaci 'liczba' lub 'liczba,liczba'",
	".ebrc: wiersz %d, klucz poza zasięgiem; podano tylko %d kolumn",
	".ebrc: książka adresowa %s nie jest regularnym plikiem",
	0,
	".ebrc: %s nie jest katalogiem",
	".ebrc: wiersz %d, zbyt wiele agentów użytkownika, limit 9",
	".ebrc: plik ciastek %s nie jest regularnym plikiem",
	".ebrc: nie można utworzyć pliku ciastek %s",
	".ebrc: zbyt wiele dyrektyw JS, limit %d",
	".ebrc: wiersz %d, domena %s nie zawiera kropki",
	".ebrc: kosz na wiadomości %s nie jest regularnym plikiem",
	".ebrc: plik z certyfikatem SSL %s nie jest regularnym plikiem",
	".ebrc: plik z certyfikatem SSL %s nie istnieje lub nie jest do odczytu",
	".ebrc: wiersz %d, słowo kluczowe %s nie jest zaimplementowane",
	".ebrc: wiele kont pocztowych ustawionych jako domyślne",
	".ebrc: brak dyrektywy 'inserver' w wierszu %d",
	".ebrc: brak dyrektywy 'outerver' w wierszu %d",
	".ebrc: brak dyrektywy 'login' w wierszu %d",
	".ebrc: brak dyrektywy 'password' w wierszu %d",
	".ebrc: brak dyrektywy 'from' w wierszu %d",
	".ebrc: brak dyrektywy 'reply' w wierszu %d",
	".ebrc: brak dyrektywy 'type' w wierszu %d",
	".ebrc: brak dyrektywy 'description' w wierszu %d",
	".ebrc: brak przyrostka lub listy protokołów w wierszu %d",
	".ebrc: brak dyrektywy 'program' w wierszu %d",
	".ebrc: brak dyrektywy 'table name' w wierszu %d",
	".ebrc: brak dyrektywy 'short name' w wierszu %d",
	".ebrc: brak dyrektywy 'columns' w wierszu %d",
	".ebrc: nieoczekiwany '}' w wierszu %d",
	".ebrc: funkcja %s nie jest domknięta przed końcem pliku",
	".ebrc: zniekształcony tekst w wierszu %d",
	".ebrc: wiersz %d, nie można rozpocząć funkcji, deskryptora MIME/poczty lub bloku filtrów wewnątrz %s",
	".ebrc: wyrażenie w wierszu %d musi się znajdować wewnątrz funkcji",
	"zbyt wiele kont pocztowych w Twoim pliku .ebrc, limit %d",
	"zbyt wiele typów MIME w Twoim pliku .ebrc, limit %d",
	"zbyt wiele tabel SQL w Twoim pliku .ebrc, limit %d",
	"zbyt wiele funkcji w Twoim pliku .ebrc, limit %d",
	".ebrc: wiersz %d, zbyt głębokie zagnieżdżenie struktur kontrolnych",
	".ebrc: funkcja %s nie jest domknięta przed końcem pliku",
	".ebrc: blok poczty lub MIME nie jest domknięty przed końcem pliku",
	"katalog domowy nie jest zdefiniowany w zmiennej $HOME",
	"%s nie jest katalogiem",
	"nie podano kont pocztowych, sprawdź swój plik konfiguracyjny .ebrc",
	"nieprawidłowy numer konta, użyj numeru od 1 do %d",
	"edbrowse  -v    (pokaż wersję)\nedbrowse -h (ta wiadomość)\nedbrowse -c (edytuj plik konfiguracyjny)\nedbrowse [-e] [-d#] -f[#] (pobierz pocztę) \nedbrowse  [-e] [-d#] -[p]m    (czytaj nieprzeczytane wiadomości)\nedbrowse  [-e] [-d#] -[p]fm[#]    (pobierz pocztę i czytaj nieprzeczytane wiadomości)\nedbrowse  [-e] [-d#] -m[#] adres1 adres2 ... plik [+załączniki]\nedbrowse  [-e] [-d#] plik1 plik2 ...",
	"podaj co najmniej jednego odbiorcę i plik do wysłania",
	"podaj co najmniej jednego odbiorcę i plik do wysłania, przed załącznikami",
	"zbyt wiele plików otwartych jednocześnie, limit %d",
	"nieprawidłowa sesja %d w fetchLineContext()",
	"nieprawidłowy numer wiersza %d w fetchLineContext()",
	"zbyt wiele kont proxy w Twoim pliku .ebrc, limit %d",
	"sesja %d poza zakresem w cxActive",
	"podwójna inicjalizacja w sesji %d",
	"zamykam nieaktywną sesję %d",
	"pusty nowy element w addToMap()",
	"brak znaku nowej linii we wpisie z katalogiem %s",
	"brak zamykającego '>' w wierszu %d",
	"funkcja fieldInBuffer nie może znaleźć tagu %d newtext %s",
	"nie można odtworzyć Twojego pliku ciastek %s",
	0,
	"klient Fetchmail jest interaktywny i nie może być uruchomiony w tle",
	"katalog skrzynki odbiorczej nie został podany w Twoim pliku .ebrc",
	"Nie można zmienić katalogu na %s",
	0,
	"login lub hasło niepoprawne",
	0,
	0,
	0,
	0,
	0,
	"po kodzie tagu %d następuje nieprawidłowy znak %c",
	0,
	"Funkcja htmlParse() nie jest wielobieżna.",
	"nieoczekiwany typ danych wejściowych w funkcji submitForm()",
	"lista = 0 w tagFromJavaVar()",
	0,
	"nie można zaalokować pamięci dla operacji JavaScript",
	"nie można utworzyć kontekstu JavaScript",
	"nie można utworzyć obiektu 'window' JavaScript",
	"nie można utworzyć standardowych klas JavaScript",
	"nie można utworzyć obiektu 'document' JavaScript",
	"ciąg 'host:port' zbyt długi",
	"ciąg 'protocol:' zbyt długi",
	"błąd alokacji %zu bajtów",
	"błąd alokacji (calloc) %zu bajtów",
	"reallocMem(p,0)",
	"reallocMem(0,%zu)",
	"błąd realokacji %zu bajtów",
	"stringInList(null,...)",
	"stringInListCI(null,...)",
	"charInList(null,...)",
	"zerowy wskaźnik w pstLength",
	"nie można użyć ioctl() aby zarządzać konsolą (tty)",
	"nie można otworzyć %s",
	"nie można utworzyć lub zapisać %s",
	"wywołanie fopen() z niewłaściwym trybem %s",
	"'/' w złym miejscu w getDirURL(%s)",
	"'/' w złym miejscu w %s",
	"decodePostData(0,0)",
	"nie można skonwertować PDF do HTML; upewnij się, że 'pdftohtml' jest zainstalowany i spróbuj wykonać go na %s",
	0,
	0,
	"nie można odpowiadać w trybie katalogu",
	"nie można odpowiadać w trybie bazy danych",
	"nie można odpowiadać na pusty plik",
	"nie można odpowiadać na plik binarny",
	"wiersze tematu i adresu zwrotnego są wymagane",
	"uwaga, brak identyfikatora wiadomości",
	"Przykro mi, nagłówki emaila nie są dostępne.\nMusisz zacząć od niesformatowanej wiadomości",
	"l rozwija znaki kontrolne do postaci szesnastkowej (hex)",
	"l rozwija znaki kontrolne i znaki spoza ASCII do postaci szesnastkowej (hex)",
	"Uwaga: funkcje wyszukiwania/podstawienia nie wspierają znaków UTF-8,\ngdyź w Twojej bibliotece 'pcre' brakuje takiej funkcjonalności.\nWywołaj 'export PCREUTF8=off' aby wyłączyć tę funkcję i nie widzieć tego ostrzeżenia",
	"konwersja do ISO-8859",
	"konwersja do UTF-8",
	"nie konwertuj pomiędzy ISO-8859 a UTF-8",
	"automatycznie konwertuj pomiędzy ISO-8859 a UTF-8",
	"nie można skopiować drzewa katalogów do kosza lub innego systemu plików;\nużyj 'cpio -p' lub 'cp -r' z poziomu powłoki",
	"nie można usunąć drzewa katalogów; użyj 'rm -r' z poziomu powłoki",
	"Nie udało się zainicjalizować libcurl",
	"Lista zawartości tego katalogu FTP jest pusta",
	"wyszukiwanie i podstawianie z użyciem ASCII",
	"wyszukiwanie i podstawianie z użyciem UTF-8",
	"Uwaga: może być konieczne (tymczasowe) wyłączenie wyszukiwania i podstawiania UTF-8\npoleceniem 'su8', aby to zadziałało",
	"klucz główny składa się z więcej niż 3 kolumn",
	"nie można wyznaczyć następnej wartości klucza seryjnego (0)",
	"Nazwy tabel znajdują się w buforze %d\n",
	"nie podano źródła danych",
	"łączenie ze źródłem danych %s\n",
	"rząd",
	"rzędy",
	"wybrane",
	"wstawione",
	"zaktualizowane",
	"usunięte",
	"procedura wykonana",
	"tabela",
	"wyrażenie SQL nie jest zakończone średnikiem, lub prawym nawiasem w następnej linii",
	"wyrażenie 'update' lub 'delete' bez opcji 'where'",
	"odmowa zdalnego dostępu",
	"Autoryzacja wymagana aby odczytac %s",
	"operacja zakończona niepowodzeniem z powodu błędu alokacji pamięci",
	"Twoja wersja libcurl jest starsza niż %u.%u.%u.\nMusisz zaktualizować by używać edbrowse",
	"przekroczenie czasu wykonania operacji",
	"nie można wysłać danych do serwera",
	"biblioteka curl zwróciła następującą informację o błędzie podczas wykonywania żądanej operacji: %s",
	"klucze obce dla %s\n",
	"nie pobieraj kolumn BLOB",
	"pobieraj kolumny BLOB",
	"błąd połączenia SSL w libcurl: %s",
	"konsola wejścia (tty)",
	"wejście readline()",
	0,
	"Nienaprawialny błąd JavaScript w bieżącej sesji, JavaScript został zamknięty",
	"obsługa 'onclick' nie działa z polem tekstowym",
	"Nie można sparsować URI danych, gdyż zawiera on JavaScript.",
};

/* English by default */
static const char **messageArray = englishMessages;
static int messageArrayLength = sizeof(englishMessages) / sizeof(char *);

int eb_lang = 1;		/* default English */
bool cons_utf8, iuConvert = true;
char type8859 = 1;

void selectLanguage(void)
{
	char buf[8];
	char *s = getenv("LANG");
	if (!s)
		return;
	if (!*s)
		return;

	if (strstrCI(s, "utf8") || strstrCI(s, "utf-8"))
		cons_utf8 = true;

/* We roll our own international messages in this file, so you wouldn't think
 * we need setlocale, but pcre needs the locale for expressions like \w,
 * and for ranges like [A-z],
 * and to convert to upper or lower case etc.
 * So I set LC_ALL, which covers both LC_CTYPE and LC_COLLATE.
 * Note however that your environment does not affect the order of files
 * in a directory listing.
 * I do the sort myself, using strcmp, rather than strcoll.
 * See qscmp() in stringfile.c */

	setlocale(LC_ALL, "");

	strncpy(buf, s, 7);
	buf[7] = 0;
	caseShift(buf, 'l');

	if (!strncmp(buf, "en", 2))
		return;		/* english is default */

	if (!strncmp(buf, "fr", 2)) {
		eb_lang = 2;
		messageArray = frenchMessages;
		messageArrayLength = sizeof(frenchMessages) / sizeof(char *);
		return;
	}

	if (!strncmp(buf, "pt_br", 5)) {
		eb_lang = 3;
		messageArray = brazilianPortugueseMessages;
		messageArrayLength =
		    sizeof(brazilianPortugueseMessages) / sizeof(char *);
		return;
	}

	if (!strncmp(buf, "pl_pl", 5)) {
		eb_lang = 4;
		messageArray = polishMessages;
		messageArrayLength = sizeof(polishMessages) / sizeof(char *);
		type8859 = 2;
		return;
	}

/* This message is really annoying if it pops up every time you invoke edbrowse.
	fprintf(stderr, "Sorry, language %s is not implemented\n", buf);
*/
}				/* selectLanguage */

static const char *getString(int msg)
{
	const char **a = messageArray;
	const char *s;
	char *t;
	int t_len;
	static char utfbuf[1000];

	if (msg >= messageArrayLength)
		a = englishMessages;
	s = a[msg];
	if (!s)
		s = englishMessages[msg];
	if (!s)
		s = "spurious message";

	if (cons_utf8)
		return s;

/* We have to convert it. */
	utf2iso(s, strlen(s), &t, &t_len);
	strcpy(utfbuf, t);
	nzFree(t);
	return utfbuf;
}				/* getString */

/*********************************************************************
Internationalize the standard puts and printf.
These are simple informational messages, where you don't need to error out,
or check the debug level, or store the error in a buffer.
The i_ prefix means international.
*********************************************************************/

void i_puts(int msg)
{
	puts(getString(msg));
}				/* i_puts */

void i_printf(int msg, ...)
{
	const char *realmsg = getString(msg);
	va_list p;
	va_start(p, msg);
	vprintf(realmsg, p);
	va_end(p);
}				/* i_printf */

/* Print and exit.  This puts newline on, like puts. */
void i_printfExit(int msg, ...)
{
	const char *realmsg = getString(msg);
	va_list p;
	va_start(p, msg);
	vfprintf(stderr, realmsg, p);
	fprintf(stderr, "\n");
	va_end(p);
	ebClose(1);
}				/* i_printfExit */

/* i_stringAndMessage: concatenate a message to an existing string. */
void i_stringAndMessage(char **s, int *l, int messageNum)
{
	const char *messageText = getString(messageNum);
	stringAndString(s, l, messageText);
}				/* i_stringAndMessage */

/*********************************************************************
The following error display functions are specific to edbrowse,
rather than extended versions of the standard unix print functions.
Thus I don't need the i_ prefix.
*********************************************************************/

char errorMsg[4000];

/* Show the error message, not just the question mark, after these commands. */
static const char showerror_cmd[] = "AbefMqrw^";

/* Set the error message.  Type h to see the message. */
void setError(int msg, ...)
{
	va_list p;

	if (msg < 0) {
		errorMsg[0] = 0;
		return;
	}

	va_start(p, msg);
	vsprintf(errorMsg, getString(msg), p);
	va_end(p);

/* sanity check */
	if (strlen(errorMsg) >= sizeof(errorMsg)) {
		i_printf(MSG_ErrorMessageLong, strlen(errorMsg));
		puts(errorMsg);
		exit(1);
	}
}				/* setError */

void showError(void)
{
	if (errorMsg[0])
		puts(errorMsg);
	else
		i_puts(MSG_NoErrors);
}				/* showError */

void showErrorConditional(char cmd)
{
	if (helpMessagesOn || strchr(showerror_cmd, cmd))
		showError();
	else
		puts("?");
}				/* showErrorConditional */

void showErrorAbort(void)
{
	errorPrint("1%s", errorMsg);
}				/* showErrorAbort */

void browseError(int msg, ...)
{
	va_list p;
	if (ismc)
		return;
	if (browseLocal != 1)
		return;
	if (browseLine) {
		i_printf(MSG_LineX, browseLine);
		cw->labels[4] = browseLine;
	} else
		i_printf(MSG_BrowseError);
	va_start(p, msg);
	vprintf(getString(msg), p);
	va_end(p);
	nl();
	browseLocal = 2;
}				/* browseError */

/* Javascript errors, we need to see these no matter what. */
void runningError(int msg, ...)
{
	va_list p;
	if (ismc)
		return;
	if (debugLevel <= 2)
		return;
	if (browseLine) {
		i_printf(MSG_LineX, browseLine);
		cw->labels[4] = browseLine;
	}
	va_start(p, msg);
	vprintf(getString(msg), p);
	va_end(p);
	nl();
	browseLocal = 2;
}				/* runningError */

/*********************************************************************
Now for the international version of caseShift.
This converts anything that might reasonably be a letter in your locale.
But it isn't ready for prime time.
I'd have to handle utf8 or not,
and then understand upper and lower case letters per language.
So this is commented out.
It was just a preliminary effort anyways, based on iso8859-1.
*********************************************************************/

#if 0

static const char upperMore[] = "";

static const char lowerMore[] = "";

static const char letterMore[] = "";

static bool i_isalphaByte(unsigned char c)
{
	if (isalphaByte(c))
		return true;
	if (c == false)
		return 0;
	if (strchr(letterMore, c))
		return true;
	return false;
}				/* i_isalphaByte */

/* assumes the arg is a letter */
static unsigned char i_tolower(unsigned char c)
{
	char *s;
	if (isalphaByte(c))
		return tolower(c);
	s = strchr(upperMore, c);
	if (s)
		c = lowerMore[s - upperMore];
	return c;
}				/* i_tolower */

static unsigned char i_toupper(unsigned char c)
{
	char *s;
	if (isalphaByte(c))
		return toupper(c);
	s = strchr(lowerMore, c);
	if (s)
		c = upperMore[s - lowerMore];
	return c;
}				/* i_toupper */

/* This is a variation on the original routine, found in stringfile.c */
void i_caseShift(unsigned char *s, char action)
{
	unsigned char c;
/* The McDonalds conversion is very English - should we do it in all languages? */
	int mc = 0;
	bool ws = true;

	for (; c = *s; ++s) {
		if (action == 'u') {
			if (i_isalphaByte(c))
				*s = i_toupper(c);
			continue;
		}

		if (action == 'l') {
			if (i_isalphaByte(c))
				*s = i_tolower(c);
			continue;
		}

/* mixed case left */
		if (i_isalphaByte(c)) {
			if (ws)
				c = i_toupper(c);
			else
				c = i_tolower(c);
			if (ws && c == 'M')
				mc = 1;
			else if (mc == 1 && c == 'c')
				mc = 2;
			else if (mc == 2) {
				c = i_toupper(c);
				mc = 0;
			} else
				mc = 0;
			*s = c;
			ws = false;
			continue;
		}

		ws = true, mc = 0;
	}			/* loop */
}				/* caseShift */

#endif
